HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class APIInfoEndpoint

    Provides all the methods required to make calls to the api_info endpoint of the Hudu API.

    Inheritance
    System.Object
    APIInfoEndpoint
    Namespace: HuduAPI.Endpoints
    Assembly: HuduAPI.dll
    Syntax
    public class APIInfoEndpoint
    Remarks

    The endpoint will return the version and date of your Hudu instance

    Constructors

    APIInfoEndpoint(String, String)

    Initializes a new instance of the APIInfoEndpoint class with the required URL and API Keys.

    Declaration
    public APIInfoEndpoint(string huduAPIKey, string huduBaseURL)
    Parameters
    Type Name Description
    System.String huduAPIKey

    The hudu API key.

    System.String huduBaseURL

    The hudu base URL.

    Properties

    HuduAPIKey

    Gets or sets the hudu API key that will be used for all calls to this Endpoint.

    Declaration
    public string HuduAPIKey { get; set; }
    Property Value
    Type Description
    System.String

    The hudu API key.

    HuduBaseURL

    Gets or sets the hudu base URL that will be used for all calls to the Endpoint.

    Declaration
    public string HuduBaseURL { get; set; }
    Property Value
    Type Description
    System.String

    The hudu base URL.

    Methods

    Get()

    Gets the current Hudu API information as returned by the api_info endpoint.

    Declaration
    public APIInfo Get()
    Returns
    Type Description
    APIInfo

    See Also

    HuduAPI.Endpoints.IEndpoint
    © Dracon80. All rights reserved.