HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class AssetLayoutsEndpoint

    Provides all the methods required to make calls to the asset_layout endpoint of the Hudu API.

    Inheritance
    System.Object
    AssetLayoutsEndpoint
    Namespace: HuduAPI.Endpoints
    Assembly: HuduAPI.dll
    Syntax
    public class AssetLayoutsEndpoint
    Remarks

    The endpoint is a full CRUD endpoint and provides all methods required to create, read, update delete and archive.

    Constructors

    AssetLayoutsEndpoint(String, String)

    Initializes a new instance of the AssetLayoutsEndpoint class.

    Declaration
    public AssetLayoutsEndpoint(string huduAPIKey, string huduBaseURL)
    Parameters
    Type Name Description
    System.String huduAPIKey

    The hudu API key.

    System.String huduBaseURL

    The hudu base URL.

    Properties

    HuduAPIKey

    Gets or sets the hudu API key that will be used for all calls to this Endpoint.

    Declaration
    public string HuduAPIKey { get; set; }
    Property Value
    Type Description
    System.String

    The hudu API key.

    HuduBaseURL

    Gets or sets the hudu base URL that will be used for all calls to the Endpoint.

    Declaration
    public string HuduBaseURL { get; set; }
    Property Value
    Type Description
    System.String

    The hudu base URL.

    Methods

    Create(CreateAssetLayout)

    Performs a Create method call on the Hudu API to create a new assetlayout

    Declaration
    public AssetLayout Create(CreateAssetLayout parameters)
    Parameters
    Type Name Description
    CreateAssetLayout parameters

    The parameters to use when making the call.

    Returns
    Type Description
    AssetLayout

    An object of type AssetLayout that represents the created object in hudu

    Get(GetAssetLayouts)

    Get AssetLayouts based on the parameters used to filter the resutls

    Declaration
    public AssetLayouts Get(GetAssetLayouts parameters)
    Parameters
    Type Name Description
    GetAssetLayouts parameters

    The parameters to use when making the call.

    Returns
    Type Description
    AssetLayouts

    A single AssetLayouts object that contains all the asset_layouts found

    Exceptions
    Type Condition
    RecordNotFoundException

    If the asset_layout is not found than an exception is raised

    Get(ItemById)

    Get a single AssetLayout from Hudu

    Declaration
    public AssetLayout Get(ItemById parameters)
    Parameters
    Type Name Description
    ItemById parameters

    The parameters to use when making the call.

    Returns
    Type Description
    AssetLayout

    A single AssetLayout Object as returned by the Hudu API

    Exceptions
    Type Condition
    RecordNotFoundException

    If the asset_layout is not found than an exception is raised

    Update(UpdateAssetLayout)

    Performs an update on the supplied AssetLayout ID using the parameters supplied.

    Declaration
    public AssetLayout Update(UpdateAssetLayout parameters)
    Parameters
    Type Name Description
    UpdateAssetLayout parameters

    The parameters to use when making the call.

    Returns
    Type Description
    AssetLayout

    An object of type AssetLayout that represents the created object in hudu

    © Dracon80. All rights reserved.