HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class FoldersEndpoint

    Provides all the methods required to make calls to the folder endpoint of the Hudu API.

    Inheritance
    System.Object
    FoldersEndpoint
    Namespace: HuduAPI.Endpoints
    Assembly: HuduAPI.dll
    Syntax
    public class FoldersEndpoint

    Constructors

    FoldersEndpoint(String, String)

    Initializes a new instance of the FoldersEndpoint class with the required API Key and Hudu URL to make all calls.

    Declaration
    public FoldersEndpoint(string huduAPIKey, string huduBaseURL)
    Parameters
    Type Name Description
    System.String huduAPIKey

    The hudu API key.

    System.String huduBaseURL

    The hudu base URL.

    Properties

    HuduAPIKey

    Gets or sets the hudu API key that will be used for all calls to this Endpoint.

    Declaration
    public string HuduAPIKey { get; set; }
    Property Value
    Type Description
    System.String

    The hudu API key.

    HuduBaseURL

    Gets or sets the hudu base URL that will be used for all calls to the Endpoint.

    Declaration
    public string HuduBaseURL { get; set; }
    Property Value
    Type Description
    System.String

    The hudu base URL.

    Methods

    Create(CreateFolder)

    Declaration
    public Folder Create(CreateFolder parameters)
    Parameters
    Type Name Description
    CreateFolder parameters
    Returns
    Type Description
    Folder

    Delete(ItemById)

    Delete the specified folder from Hudu

    Declaration
    public void Delete(ItemById parameters)
    Parameters
    Type Name Description
    ItemById parameters

    The folder ID to use when making the call.

    Get(GetFolders)

    Get a list of folder objects from the Hudu Endpoint

    Declaration
    public Folders Get(GetFolders parameters)
    Parameters
    Type Name Description
    GetFolders parameters

    The parameters to use when making the call.

    Returns
    Type Description
    Folders

    A Folders objec that contains a list of folders found in hudu

    Get(ItemById)

    Gets a single Folder object from the Hudu API using the supplied Item ID

    Declaration
    public Folder Get(ItemById parameters)
    Parameters
    Type Name Description
    ItemById parameters

    The folder ID to use when making the call.

    Returns
    Type Description
    Folder

    A Folder object that represents the required folder in hudu

    Update(UpdateFolder)

    Update an existing folder with the new details.

    Declaration
    public Folder Update(UpdateFolder parameters)
    Parameters
    Type Name Description
    UpdateFolder parameters

    The parameters to use when making the call.

    Returns
    Type Description
    Folder

    A Folder object that represents the updated object in hudu

    See Also

    HuduAPI.Endpoints.IEndpoint
    © Dracon80. All rights reserved.