HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class MatchersEndpoint

    Provides all the methods required to make calls to the Matchers endpoint of the Hudu API.

    Inheritance
    System.Object
    MatchersEndpoint
    Namespace: HuduAPI.Endpoints
    Assembly: HuduAPI.dll
    Syntax
    public class MatchersEndpoint

    Constructors

    MatchersEndpoint(String, String)

    Initializes a new instance of the class with the required API Key and Hudu URL to make all calls.

    Declaration
    public MatchersEndpoint(string huduAPIKey, string huduBaseURL)
    Parameters
    Type Name Description
    System.String huduAPIKey

    The hudu API key.

    System.String huduBaseURL

    The hudu base URL.

    Properties

    HuduAPIKey

    Gets or sets the hudu API key that will be used for all calls to this Endpoint.

    Declaration
    public string HuduAPIKey { get; set; }
    Property Value
    Type Description
    System.String

    The hudu API key.

    HuduBaseURL

    Gets or sets the hudu base URL that will be used for all calls to the Endpoint.

    Declaration
    public string HuduBaseURL { get; set; }
    Property Value
    Type Description
    System.String

    The hudu base URL.

    Methods

    Delete(ItemById)

    Delete the specified Matcher from Hudu

    Declaration
    public void Delete(ItemById parameters)
    Parameters
    Type Name Description
    ItemById parameters

    The Matcher ID to use when making the call.

    Get(GetMatchers)

    Get a list of Matcher objects from the Hudu Endpoint

    Declaration
    public Matchers Get(GetMatchers parameters)
    Parameters
    Type Name Description
    GetMatchers parameters

    The parameters to use when making the call.

    Returns
    Type Description
    Matchers

    A Matchers objec that contains a list of Matchers found in hudu

    Update(UpdateMatcher)

    Update an existing Matcher with the new details.

    Declaration
    public Matcher Update(UpdateMatcher parameters)
    Parameters
    Type Name Description
    UpdateMatcher parameters

    The parameters to use when making the call.

    Returns
    Type Description
    Matcher

    A Matcher object that represents the updated object in hudu

    See Also

    HuduAPI.Endpoints.IEndpoint
    © Dracon80. All rights reserved.