HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Namespace HuduAPI.Endpoints.Parameters.AbstractBases

    Classes

    Article
    ArticleBuilder<TResult, TBuilder>

    An abstract builder to help build Article parameters for implementing classes.

    Asset

    An asbstract class providing all the common properties to call the hudu endpoint api/v1/companies/:company_id/assets

    AssetBuilder<TResult, TBuilder>

    Builder for the class Asset

    AssetCustomField
    AssetCustomFieldJsonConverter
    AssetLayout

    Defines the properties to be used when creating a new AssetLayout in Hudu using the endpoint api/v1/asset_layouts

    AssetLayoutBuilder<TResult, TBuilder>

    An abstract builder to help build Article parameters for implementing classes.

    AssetPassword

    Provides all the properties that define an asset_password to be used when calling the endpoint api/v1/asset_passwords

    AssetPasswordBuilder<TResult, TBuilder>

    Builder for the class CreateAssetPassword

    Company

    Provides all the common properties required to create or update a company using the hudu endpoint api/v1/companies

    CompanyBuilder<TResult, TBuilder>

    An abstract builder for the class for the Abstract Company Class that will be implemented by both update and create classes.

    Folder

    Provides all the properties needed to create a new folder using the hudu endpoint api/v1/folders

    FolderBuilder<TResult, TBuilder>

    Builder for the class CreateFolder

    Website

    Provides all the properties required to create or update a website using the hudu endpoint api/v1/websites

    WebsiteBuilder<TResult, TBuilder>

    Builder for the class CreateWebsite

    © Dracon80. All rights reserved.