HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class Article

    Inheritance
    System.Object
    Article
    CreateArticle
    UpdateArticle
    Namespace: HuduAPI.Endpoints.Parameters.AbstractBases
    Assembly: HuduAPI.dll
    Syntax
    public abstract class Article

    Properties

    CompanyId

    Gets or sets the company identifier Used to associate article with company.

    Declaration
    [JsonProperty("company_id")]
    public int? CompanyId { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    Content

    Gets or sets the content of the article.

    Declaration
    [JsonProperty("content")]
    public string Content { get; set; }
    Property Value
    Type Description
    System.String

    EnableSharing

    Gets or sets a value indicating whether the article is shared. When true, this article has a public URL for users to view it non-authenticated.

    Declaration
    [JsonProperty("enable_sharing")]
    public bool EnableSharing { get; set; }
    Property Value
    Type Description
    System.Boolean

    FolderId

    Gets or sets the id Used to associate article with folder.

    Declaration
    [JsonProperty("folder_id")]
    public int? FolderId { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    The folder identifier.

    Name

    Gets or sets the name of the article.

    Declaration
    [JsonProperty("name")]
    public string Name { get; set; }
    Property Value
    Type Description
    System.String
    © Dracon80. All rights reserved.