HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class ArticleBuilder<TResult, TBuilder>

    An abstract builder to help build Article parameters for implementing classes.

    Inheritance
    System.Object
    ArticleBuilder<TResult, TBuilder>
    CreateArticleBuilder
    UpdateArticleBuilder
    Namespace: HuduAPI.Endpoints.Parameters.AbstractBases
    Assembly: HuduAPI.dll
    Syntax
    public abstract class ArticleBuilder<TResult, TBuilder>
        where TResult : Article where TBuilder : ArticleBuilder<TResult, TBuilder>
    Type Parameters
    Name Description
    TResult

    The type of the paramater to build.

    TBuilder

    The type of the builder that is inherting this base class.

    Fields

    _companyId

    Declaration
    protected int? _companyId
    Field Value
    Type Description
    System.Nullable<System.Int32>

    _content

    Declaration
    protected string _content
    Field Value
    Type Description
    System.String

    _enableSharing

    Declaration
    protected bool _enableSharing
    Field Value
    Type Description
    System.Boolean

    _folderId

    Declaration
    protected int? _folderId
    Field Value
    Type Description
    System.Nullable<System.Int32>

    _name

    Declaration
    protected string _name
    Field Value
    Type Description
    System.String

    Methods

    Build()

    Build a class of type TResult with all the defined values

    Declaration
    public abstract TResult Build()
    Returns
    Type Description
    TResult

    Returns a TResult class

    WithCompanyId(Int32)

    Set a value for companyId

    Declaration
    public TBuilder WithCompanyId(int companyId)
    Parameters
    Type Name Description
    System.Int32 companyId

    The company identifier.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithContent(String)

    Set a value for content

    Declaration
    public TBuilder WithContent(string content)
    Parameters
    Type Name Description
    System.String content

    The content.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithEnableSharing(Boolean)

    Set a value for enableSharing

    Declaration
    public TBuilder WithEnableSharing(bool enableSharing)
    Parameters
    Type Name Description
    System.Boolean enableSharing

    if set to true [enable sharing].

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithFolderId(Int32)

    Set a value for folderId

    Declaration
    public TBuilder WithFolderId(int folderId)
    Parameters
    Type Name Description
    System.Int32 folderId

    The folder identifier.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithName(String)

    Set a value for name

    Declaration
    public TBuilder WithName(string name)
    Parameters
    Type Name Description
    System.String name

    The name.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    © Dracon80. All rights reserved.