HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class AssetLayout

    Defines the properties to be used when creating a new AssetLayout in Hudu using the endpoint api/v1/asset_layouts

    Inheritance
    System.Object
    AssetLayout
    CreateAssetLayout
    UpdateAssetLayout
    Namespace: HuduAPI.Endpoints.Parameters.AbstractBases
    Assembly: HuduAPI.dll
    Syntax
    public abstract class AssetLayout

    Constructors

    AssetLayout(String, String, Color, Color, List<AssetLayoutField>)

    An Abstract class that contains all the common properties for both the Create and Update methods on the hudu endpoing api/v1/asset_layouts.

    Declaration
    public AssetLayout(string name, string icon, Color color, Color iconColor, List<AssetLayoutField> assetLayoutFields)
    Parameters
    Type Name Description
    System.String name

    The name of the new asset_layout.

    System.String icon

    The Icon class name, example: “fas fa-home”.

    System.Drawing.Color color

    The Color for background color.

    System.Drawing.Color iconColor

    Color of the icon foreground.

    List<AssetLayoutField> assetLayoutFields

    The asset layout fields.

    Remarks

    All other properties of the class are optional properties that can safely be left blank and still be able to call the endpoint

    Fields

    _color

    Declaration
    protected readonly Color _color
    Field Value
    Type Description
    System.Drawing.Color

    _iconColor

    Declaration
    protected readonly Color _iconColor
    Field Value
    Type Description
    System.Drawing.Color

    Properties

    Color

    The background color of the Icon

    Declaration
    [JsonProperty("color")]
    public string Color { get; }
    Property Value
    Type Description
    System.String

    Fields

    A list of fields defined for this asset_layout

    Declaration
    [JsonProperty("fields")]
    public List<AssetLayoutField> Fields { get; }
    Property Value
    Type Description
    List<AssetLayoutField>

    Icon

    Icon class name, example: “fas fa-home”

    Declaration
    [JsonProperty("icon")]
    public string Icon { get; }
    Property Value
    Type Description
    System.String

    IconColor

    The foreground color of the Icon

    Declaration
    [JsonProperty("icon_color")]
    public string IconColor { get; }
    Property Value
    Type Description
    System.String

    IncludeComments

    Allow comments to be attached to this asset_layout

    Declaration
    [JsonProperty("include_comments")]
    public bool IncludeComments { get; set; }
    Property Value
    Type Description
    System.Boolean

    IncludeFiles

    Allow files to be attached to this asset_layout

    Declaration
    [JsonProperty("include_files")]
    public bool IncludeFiles { get; set; }
    Property Value
    Type Description
    System.Boolean

    IncludePasswords

    Allow passwords to be attached to this asset_layout

    Declaration
    [JsonProperty("include_passwords")]
    public bool IncludePasswords { get; set; }
    Property Value
    Type Description
    System.Boolean

    IncludePhotos

    Allow photos to be attached to this asset_layout

    Declaration
    [JsonProperty("include_photos")]
    public bool IncludePhotos { get; set; }
    Property Value
    Type Description
    System.Boolean

    Name

    The name of the asset_layout to be created

    Declaration
    [JsonProperty("name")]
    public string Name { get; }
    Property Value
    Type Description
    System.String

    PasswordTypes

    List of password types, separated with new line characters

    Declaration
    [JsonProperty("password_types")]
    public string PasswordTypes { get; set; }
    Property Value
    Type Description
    System.String
    © Dracon80. All rights reserved.