HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class CompanyBuilder<TResult, TBuilder>

    An abstract builder for the class for the Abstract Company Class that will be implemented by both update and create classes.

    Inheritance
    System.Object
    CompanyBuilder<TResult, TBuilder>
    CreateCompanyBuilder
    UpdateCompanyBuilder
    Namespace: HuduAPI.Endpoints.Parameters.AbstractBases
    Assembly: HuduAPI.dll
    Syntax
    public abstract class CompanyBuilder<TResult, TBuilder>
        where TResult : Company where TBuilder : CompanyBuilder<TResult, TBuilder>
    Type Parameters
    Name Description
    TResult
    TBuilder

    Fields

    _addressLine1

    Declaration
    protected string _addressLine1
    Field Value
    Type Description
    System.String

    _addressLine2

    Declaration
    protected string _addressLine2
    Field Value
    Type Description
    System.String

    _city

    Declaration
    protected string _city
    Field Value
    Type Description
    System.String

    _companyType

    Declaration
    protected string _companyType
    Field Value
    Type Description
    System.String

    _countryName

    Declaration
    protected string _countryName
    Field Value
    Type Description
    System.String

    _faxNumber

    Declaration
    protected string _faxNumber
    Field Value
    Type Description
    System.String

    _idNumber

    Declaration
    protected string _idNumber
    Field Value
    Type Description
    System.String

    _name

    Declaration
    protected readonly string _name
    Field Value
    Type Description
    System.String

    _nickname

    Declaration
    protected string _nickname
    Field Value
    Type Description
    System.String

    _notes

    Declaration
    protected string _notes
    Field Value
    Type Description
    System.String

    _parentCompanyId

    Declaration
    protected int? _parentCompanyId
    Field Value
    Type Description
    System.Nullable<System.Int32>

    _phoneNumber

    Declaration
    protected string _phoneNumber
    Field Value
    Type Description
    System.String

    _state

    Declaration
    protected string _state
    Field Value
    Type Description
    System.String

    _website

    Declaration
    protected string _website
    Field Value
    Type Description
    System.String

    _zip

    Declaration
    protected string _zip
    Field Value
    Type Description
    System.String

    Methods

    Build()

    Builds a new instance of type TResult.

    Declaration
    public abstract TResult Build()
    Returns
    Type Description
    TResult

    WithAddressLine1(String)

    Set a value for addressLine1

    Declaration
    public TBuilder WithAddressLine1(string addressLine1)
    Parameters
    Type Name Description
    System.String addressLine1

    The address line1.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithAddressLine2(String)

    Set a value for addressLine2

    Declaration
    public TBuilder WithAddressLine2(string addressLine2)
    Parameters
    Type Name Description
    System.String addressLine2

    The address line2.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithCity(String)

    Set a value for city

    Declaration
    public TBuilder WithCity(string city)
    Parameters
    Type Name Description
    System.String city

    The city.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithCompanyType(String)

    Set a value for companyType

    Declaration
    public TBuilder WithCompanyType(string companyType)
    Parameters
    Type Name Description
    System.String companyType

    Type of the company.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithCountryName(String)

    Set a value for countryName

    Declaration
    public TBuilder WithCountryName(string countryName)
    Parameters
    Type Name Description
    System.String countryName

    Name of the country.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithFaxNumber(String)

    Set a value for faxNumber

    Declaration
    public TBuilder WithFaxNumber(string faxNumber)
    Parameters
    Type Name Description
    System.String faxNumber

    The fax number.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithIdNumber(String)

    Set a value for idNumber

    Declaration
    public TBuilder WithIdNumber(string idNumber)
    Parameters
    Type Name Description
    System.String idNumber

    The identifier number.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithNickname(String)

    Set a value for nickname

    Declaration
    public TBuilder WithNickname(string nickname)
    Parameters
    Type Name Description
    System.String nickname

    The nickname.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithNotes(String)

    Set a value for notes

    Declaration
    public TBuilder WithNotes(string notes)
    Parameters
    Type Name Description
    System.String notes

    The notes.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithParentCompanyId(Nullable<Int32>)

    Set a value for parentCompanyId

    Declaration
    public TBuilder WithParentCompanyId(int? parentCompanyId)
    Parameters
    Type Name Description
    System.Nullable<System.Int32> parentCompanyId

    The parent company identifier.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithPhoneNumber(String)

    Set a value for phoneNumber

    Declaration
    public TBuilder WithPhoneNumber(string phoneNumber)
    Parameters
    Type Name Description
    System.String phoneNumber

    The phone number.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithState(String)

    Set a value for state

    Declaration
    public TBuilder WithState(string state)
    Parameters
    Type Name Description
    System.String state

    The state.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithWebsite(String)

    Set a value for website

    Declaration
    public TBuilder WithWebsite(string website)
    Parameters
    Type Name Description
    System.String website

    The website.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    WithZip(String)

    Set a value for zip

    Declaration
    public TBuilder WithZip(string zip)
    Parameters
    Type Name Description
    System.String zip

    The zip.

    Returns
    Type Description
    TBuilder

    A generic Builder Object for type TBuilder

    © Dracon80. All rights reserved.