HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class AssetLayoutField

    Defines the attributes of an Asset Layout Field. All requried properties are included in the constructor of the class. All other properties are optional when making a call to the endpoint api/v1/asset_layouts

    Inheritance
    System.Object
    AssetLayoutField
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class AssetLayoutField

    Constructors

    AssetLayoutField(String, AssetLayoutFieldType)

    Initializes a new instance of the AssetLayoutField class with the requried fields populated ready for posting.

    Declaration
    public AssetLayoutField(string label, AssetLayoutFieldType fieldtype)
    Parameters
    Type Name Description
    System.String label

    Label (used as name) of input.

    AssetLayoutFieldType fieldtype

    The type of Field to be created.

    Properties

    Expiration

    Whether to Add to Expiration List in hudu

    Declaration
    [JsonProperty("expiration")]
    public bool Expiration { get; set; }
    Property Value
    Type Description
    System.Boolean

    FieldType

    The type of Field to be created

    Declaration
    [JsonProperty("field_type")]
    public string FieldType { get; }
    Property Value
    Type Description
    System.String

    Hint

    Hint shown below input box

    Declaration
    [JsonProperty("hint")]
    public string Hint { get; set; }
    Property Value
    Type Description
    System.String

    Label

    Label (used as name) of input

    Declaration
    [JsonProperty("label")]
    public string Label { get; }
    Property Value
    Type Description
    System.String

    LinkableId

    ID of Asset Layout to pull values from

    Declaration
    [JsonProperty("linkable_id")]
    public int? LinkableId { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    Max

    Maximum Integer value that can be set on an Number field

    Declaration
    [JsonProperty("max")]
    public int? Max { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    Min

    Minimum Integer value that can be set on an Number field

    Declaration
    [JsonProperty("min")]
    public int? Min { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    Options

    List of options for dropdown, separated with new line characters

    Declaration
    [JsonProperty("options")]
    public string Options { get; set; }
    Property Value
    Type Description
    System.String

    Position

    Leave blank to have auto-filled

    Declaration
    [JsonProperty("position")]
    public int? Position { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    Required

    Whether to make this value required on form fills

    Declaration
    [JsonProperty("required")]
    public bool Required { get; set; }
    Property Value
    Type Description
    System.Boolean

    ShowInList

    Whether to show this value in list view or not

    Declaration
    [JsonProperty("show_in_list")]
    public bool ShowInList { get; set; }
    Property Value
    Type Description
    System.Boolean
    © Dracon80. All rights reserved.