HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class CreateAssetPassword

    Provides all the properties that define a new asset_password to be created in hudu using the endpoint api/v1/asset_passwords

    Inheritance
    System.Object
    AssetPassword
    CreateAssetPassword
    Implements
    IParameters
    Inherited Members
    AssetPassword.CompanyId
    AssetPassword.Description
    AssetPassword.InPortal
    AssetPassword.Name
    AssetPassword.OtpSecret
    AssetPassword.Password
    AssetPassword.PasswordableId
    AssetPassword.PasswordableType
    AssetPassword.PasswordFolderId
    AssetPassword.PasswordType
    AssetPassword.Url
    AssetPassword.Username
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class CreateAssetPassword : AssetPassword, IParameters

    Constructors

    CreateAssetPassword(Int32, String, String)

    Initializes a new instance of the CreateAssetPassword class.

    Declaration
    public CreateAssetPassword(int companyId, string name, string password)
    Parameters
    Type Name Description
    System.Int32 companyId

    The company identifier to associate the password with.

    System.String name

    The name of the password.

    System.String password

    The password value in plain text.

    Properties

    PayloadType

    Declaration
    public string PayloadType { get; }
    Property Value
    Type Description
    System.String

    Implements

    IParameters
    © Dracon80. All rights reserved.