HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class CreateMagicDash

    Provides all the properties used to create a new, or update an existing magic_dash item using the endpoint api/v1/magic_dash

    Inheritance
    System.Object
    CreateMagicDash
    Implements
    IParameters
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class CreateMagicDash : IParameters

    Constructors

    CreateMagicDash(String, String, String)

    Initializes a new instance of the CreateMagicDash class with the required properties to create or update an existing magic_dash.

    Declaration
    public CreateMagicDash(string title, string company_name, string message)
    Parameters
    Type Name Description
    System.String title

    The title of the magic_dash.

    System.String company_name

    Name of the company to associate the magic_dash with.

    System.String message

    The message to be displayed on the magic_dash.

    Properties

    CompanyName

    This is the attribute we use to match to an existing company. If there is an existing Magic Dash Item with matching title and company_name, then it will match into that item.

    Declaration
    [JsonProperty("company_name")]
    public string CompanyName { get; }
    Property Value
    Type Description
    System.String

    Content

    Either fill this in, or content_link, or leave both blank. Fill in with HTML (tables, images, videos, etc.) to display more content in your Magic Dash Item.

    Declaration
    [JsonProperty("content")]
    public string Content { get; set; }
    Property Value
    Type Description
    System.String

    ContentLink

    This will be the first content that will be displayed on the Magic Dash Item.

    Declaration
    [JsonProperty("content_link")]
    public string ContentLink { get; set; }
    Property Value
    Type Description
    System.String

    Icon

    Use a (FontAwesome icon for the header of a Magic Dash Item. Must be in the format of fas fa-circle

    Declaration
    [JsonProperty("icon")]
    public string Icon { get; set; }
    Property Value
    Type Description
    System.String
    Remarks

    Either fill this in, or image_url. Setting this property will reset ImageUrl to null.

    ImageUrl

    Gets or Sets a URL to an image that is ssed in the header of a Magic Dash Item. Either fill this in, or Icon.

    Declaration
    [JsonProperty("image_url")]
    public string ImageUrl { get; set; }
    Property Value
    Type Description
    System.String
    Remarks

    Either fill this in, or icon. Setting this property will reset Icon to null.

    Message

    This will be the first content that will be displayed on the Magic Dash Item.

    Declaration
    [JsonProperty("message")]
    public string Message { get; }
    Property Value
    Type Description
    System.String

    PayloadType

    Declaration
    public string PayloadType { get; }
    Property Value
    Type Description
    System.String

    Shade

    Use a different color for your Magic Dash Item for different contextual states.

    Declaration
    [JsonProperty("shade")]
    public string Shade { get; set; }
    Property Value
    Type Description
    System.String
    Remarks

    Options are to leave it blank, success, or danger (not case sensitive). Setting to any other string value will result in a blank shade.

    Title

    This is the title. If there is an existing Magic Dash Item with matching title and company_name, then it will match into that item.

    Declaration
    [JsonProperty("title")]
    public string Title { get; }
    Property Value
    Type Description
    System.String

    Implements

    IParameters
    © Dracon80. All rights reserved.