HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetActivityLogs

    A parameter object for the hudu endpoint api/v1/activity_logs. The values provided to the fields or constructor help narrow down the returned results of the get query. All fields default to null, which is acceptable by the Hudu API.

    Inheritance
    System.Object
    GetActivityLogs
    Implements
    IParameters
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    [JsonObject(NamingStrategyType = typeof(SnakeCaseNamingStrategy))]
    public class GetActivityLogs : IParameters

    Properties

    ActionMessage

    Gets or sets the action message. Which is used to filter logs by action

    Declaration
    [JsonProperty("action_message")]
    public string ActionMessage { get; set; }
    Property Value
    Type Description
    System.String

    The action message to filter by.

    Page

    Gets or sets the current page of results to get.

    Declaration
    [JsonProperty("page")]
    public int? Page { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    The page.

    PageSize

    Gets or sets the number of results to return.

    Declaration
    [JsonProperty("page_size")]
    public int? PageSize { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    The size of the page.

    PayloadType

    Declaration
    public string PayloadType { get; }
    Property Value
    Type Description
    System.String

    ResourceID

    Gets or sets the resource identifier. Which filters logs by resource id. Must be coupled with resource_type

    Declaration
    [JsonProperty("resource_id")]
    public int? ResourceID { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    The resource identifier.

    ResourceType

    Gets or sets the type of the resource to filter the logs by (Asset, AssetPassword, Company, Article, etc.). Must be coupled with resource_id

    Declaration
    [JsonProperty("resource_type")]
    public string ResourceType { get; set; }
    Property Value
    Type Description
    System.String

    The type of the resource.

    StartDate

    Gets or sets the start date to filter logs by. Must be in ISO 8601 format.

    Declaration
    [JsonProperty("start_date")]
    public string StartDate { get; set; }
    Property Value
    Type Description
    System.String

    The start date.

    UserEmail

    Gets or sets the user email address to filter logs by.

    Declaration
    [JsonProperty("user_email")]
    public string UserEmail { get; set; }
    Property Value
    Type Description
    System.String

    The user email.

    UserID

    Gets or sets the user identifier to filter logs by.

    Declaration
    [JsonProperty("user_id")]
    public int? UserID { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    The user identifier.

    Implements

    IParameters

    See Also

    IParameters
    © Dracon80. All rights reserved.