HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetActivityLogsBuilder

    Builder for the class GetActivityLogs

    Inheritance
    System.Object
    GetActivityLogsBuilder
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class GetActivityLogsBuilder

    Constructors

    GetActivityLogsBuilder()

    Create a new instance for the GetActivityLogsBuilder

    Declaration
    public GetActivityLogsBuilder()

    Methods

    Build()

    Build a class of type GetActivityLogs with all the defined values

    Declaration
    public GetActivityLogs Build()
    Returns
    Type Description
    GetActivityLogs

    Returns a GetActivityLogs class

    Reset()

    Reset all properties' to the default value

    Declaration
    public GetActivityLogsBuilder Reset()
    Returns
    Type Description
    GetActivityLogsBuilder

    Returns the GetActivityLogsBuilder with the properties reseted

    WithActionMessage(String)

    Set a value of type string for the property actionMessage

    Declaration
    public GetActivityLogsBuilder WithActionMessage(string actionMessage)
    Parameters
    Type Name Description
    System.String actionMessage

    A value of type string will the defined for the property

    Returns
    Type Description
    GetActivityLogsBuilder

    Returns the GetActivityLogsBuilder with the property actionMessage defined

    WithPage(Int32)

    Set a value of type int for the property page

    Declaration
    public GetActivityLogsBuilder WithPage(int page)
    Parameters
    Type Name Description
    System.Int32 page

    A value of type int will the defined for the property

    Returns
    Type Description
    GetActivityLogsBuilder

    Returns the GetActivityLogsBuilder with the property page defined

    WithPageSize(Int32)

    Set a value of type int for the property pageSize

    Declaration
    public GetActivityLogsBuilder WithPageSize(int pageSize)
    Parameters
    Type Name Description
    System.Int32 pageSize

    A value of type int will the defined for the property

    Returns
    Type Description
    GetActivityLogsBuilder

    Returns the GetActivityLogsBuilder with the property pageSize defined

    WithResourceID(Int32)

    Set a value of type int for the property resourceId

    Declaration
    public GetActivityLogsBuilder WithResourceID(int resourceId)
    Parameters
    Type Name Description
    System.Int32 resourceId

    A value of type int will the defined for the property

    Returns
    Type Description
    GetActivityLogsBuilder

    Returns the GetActivityLogsBuilder with the property resourceId defined

    WithResourceType(String)

    Set a value of type string for the property resourceType

    Declaration
    public GetActivityLogsBuilder WithResourceType(string resourceType)
    Parameters
    Type Name Description
    System.String resourceType

    A value of type string will the defined for the property

    Returns
    Type Description
    GetActivityLogsBuilder

    Returns the GetActivityLogsBuilder with the property resourceType defined

    WithStartDate(String)

    Set a value of type string for the property startDate

    Declaration
    public GetActivityLogsBuilder WithStartDate(string startDate)
    Parameters
    Type Name Description
    System.String startDate

    A value of type string will the defined for the property

    Returns
    Type Description
    GetActivityLogsBuilder

    Returns the GetActivityLogsBuilder with the property startDate defined

    WithUserEmail(String)

    Set a value of type string for the property userEmail

    Declaration
    public GetActivityLogsBuilder WithUserEmail(string userEmail)
    Parameters
    Type Name Description
    System.String userEmail

    A value of type string will the defined for the property

    Returns
    Type Description
    GetActivityLogsBuilder

    Returns the GetActivityLogsBuilder with the property userEmail defined

    WithUserID(Int32)

    Set a value of type int for the property userId

    Declaration
    public GetActivityLogsBuilder WithUserID(int userId)
    Parameters
    Type Name Description
    System.Int32 userId

    A value of type int will the defined for the property

    Returns
    Type Description
    GetActivityLogsBuilder

    Returns the GetActivityLogsBuilder with the property userId defined

    © Dracon80. All rights reserved.