HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetAssetPasswordsBuilder

    Builder for the class GetAssetPasswords

    Inheritance
    System.Object
    GetAssetPasswordsBuilder
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class GetAssetPasswordsBuilder

    Constructors

    GetAssetPasswordsBuilder()

    Create a new instance for the GetAssetPasswordsBuilder

    Declaration
    public GetAssetPasswordsBuilder()

    Methods

    Build()

    Build a class of type GetAssetPasswords with all the defined values

    Declaration
    public GetAssetPasswords Build()
    Returns
    Type Description
    GetAssetPasswords

    Returns a GetAssetPasswords class

    Reset()

    Reset all properties' to the default value

    Declaration
    public GetAssetPasswordsBuilder Reset()
    Returns
    Type Description
    GetAssetPasswordsBuilder

    Returns the GetAssetPasswordsBuilder with the properties reseted

    WithCompanyID(Int32)

    Set a value of type int for the property companyId

    Declaration
    public GetAssetPasswordsBuilder WithCompanyID(int companyId)
    Parameters
    Type Name Description
    System.Int32 companyId

    A value of type int will the defined for the property

    Returns
    Type Description
    GetAssetPasswordsBuilder

    Returns the GetAssetPasswordsBuilder with the property companyId defined

    WithName(String)

    Set a value of type string for the property name

    Declaration
    public GetAssetPasswordsBuilder WithName(string name)
    Parameters
    Type Name Description
    System.String name

    A value of type string will the defined for the property

    Returns
    Type Description
    GetAssetPasswordsBuilder

    Returns the GetAssetPasswordsBuilder with the property name defined

    WithPage(Int32)

    Set a value of type int?? for the property page

    Declaration
    public GetAssetPasswordsBuilder WithPage(int page)
    Parameters
    Type Name Description
    System.Int32 page

    A value of type int will the defined for the property

    Returns
    Type Description
    GetAssetPasswordsBuilder

    Returns the GetAssetPasswordsBuilder with the property page defined

    WithPageSize(Int32)

    Set a value of type int?? for the property pageSize

    Declaration
    public GetAssetPasswordsBuilder WithPageSize(int pageSize)
    Parameters
    Type Name Description
    System.Int32 pageSize

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetAssetPasswordsBuilder

    Returns the GetAssetPasswordsBuilder with the property pageSize defined

    © Dracon80. All rights reserved.