HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetAssets

    Provides all the filters that can be used when calling a the get method on api/v1/assets

    Inheritance
    System.Object
    GetAssets
    Implements
    IParameters
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class GetAssets : IParameters

    Properties

    Archived

    Set to true to only show archived results.

    Declaration
    [JsonProperty("archived")]
    public Boolean Archived { get; set; }
    Property Value
    Type Description
    Boolean

    AssetLayoutId

    id of the requested asset layout.

    Declaration
    [JsonProperty("asset_layout_id")]
    public int? AssetLayoutId { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    CompanyId

    id of the requested parent Company.

    Declaration
    [JsonProperty("company_id")]
    public int? CompanyId { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    Id

    id of the requested Asset

    Declaration
    [JsonProperty("id")]
    public int? Id { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    Name

    filter by name.

    Declaration
    [JsonProperty("name")]
    public string Name { get; set; }
    Property Value
    Type Description
    System.String

    Page

    Gets or sets the page to return when paging through results.

    Declaration
    [JsonProperty("page")]
    public int? Page { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    PageSize

    The number of results to return on each page.

    Declaration
    [JsonProperty("page_size")]
    public int? PageSize { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    PayloadType

    Declaration
    public string PayloadType { get; }
    Property Value
    Type Description
    System.String

    PrimarySerial

    filter by primary serial.

    Declaration
    [JsonProperty("primary_serial")]
    public string PrimarySerial { get; set; }
    Property Value
    Type Description
    System.String

    Implements

    IParameters
    © Dracon80. All rights reserved.