HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetAssetsBuilder

    Builder for the class GetAssets

    Inheritance
    System.Object
    GetAssetsBuilder
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class GetAssetsBuilder

    Constructors

    GetAssetsBuilder()

    Create a new instance for the GetAssetsBuilder

    Declaration
    public GetAssetsBuilder()

    Methods

    Build()

    Build a class of type GetAssets with all the defined values

    Declaration
    public GetAssets Build()
    Returns
    Type Description
    GetAssets

    Returns a GetAssets class

    Reset()

    Reset all properties' to the default value

    Declaration
    public GetAssetsBuilder Reset()
    Returns
    Type Description
    GetAssetsBuilder

    Returns the GetAssetsBuilder with the properties reseted

    WithArchived(Boolean)

    Set a value of type bool for the property archived

    Declaration
    public GetAssetsBuilder WithArchived(Boolean archived)
    Parameters
    Type Name Description
    Boolean archived

    A value of type bool will the defined for the property

    Returns
    Type Description
    GetAssetsBuilder

    Returns the GetAssetsBuilder with the property archived defined

    WithAssetLayoutId(Int32)

    Set a value of type int?? for the property assetLayoutId

    Declaration
    public GetAssetsBuilder WithAssetLayoutId(int assetLayoutId)
    Parameters
    Type Name Description
    System.Int32 assetLayoutId

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetAssetsBuilder

    Returns the GetAssetsBuilder with the property assetLayoutId defined

    WithCompanyId(Int32)

    Set a value of type int?? for the property companyId

    Declaration
    public GetAssetsBuilder WithCompanyId(int companyId)
    Parameters
    Type Name Description
    System.Int32 companyId

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetAssetsBuilder

    Returns the GetAssetsBuilder with the property companyId defined

    WithId(Int32)

    Set a value of type int?? for the property id

    Declaration
    public GetAssetsBuilder WithId(int id)
    Parameters
    Type Name Description
    System.Int32 id

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetAssetsBuilder

    Returns the GetAssetsBuilder with the property id defined

    WithName(String)

    Set a value of type string for the property name

    Declaration
    public GetAssetsBuilder WithName(string name)
    Parameters
    Type Name Description
    System.String name

    A value of type string will the defined for the property

    Returns
    Type Description
    GetAssetsBuilder

    Returns the GetAssetsBuilder with the property name defined

    WithPage(Int32)

    Set a value of type int?? for the property page

    Declaration
    public GetAssetsBuilder WithPage(int page)
    Parameters
    Type Name Description
    System.Int32 page

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetAssetsBuilder

    Returns the GetAssetsBuilder with the property page defined

    WithPageSize(Int32)

    Set a value of type int?? for the property pageSize

    Declaration
    public GetAssetsBuilder WithPageSize(int pageSize)
    Parameters
    Type Name Description
    System.Int32 pageSize

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetAssetsBuilder

    Returns the GetAssetsBuilder with the property pageSize defined

    WithPrimarySerial(String)

    Set a value of type string for the property primarySerial

    Declaration
    public GetAssetsBuilder WithPrimarySerial(string primarySerial)
    Parameters
    Type Name Description
    System.String primarySerial

    A value of type string will the defined for the property

    Returns
    Type Description
    GetAssetsBuilder

    Returns the GetAssetsBuilder with the property primarySerial defined

    © Dracon80. All rights reserved.