HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetCompanies

    Paramaters to get a list of companies from hudu

    Inheritance
    System.Object
    GetCompanies
    Implements
    IParameters
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    [JsonObject(NamingStrategyType = typeof(SnakeCaseNamingStrategy))]
    public class GetCompanies : IParameters

    Properties

    City

    Gets or sets the city to filter companies by.

    Declaration
    public string City { get; set; }
    Property Value
    Type Description
    System.String

    The city.

    IDNumber

    Gets or sets the identifier number to filter companies by.

    Declaration
    [JsonProperty("id_number")]
    public string IDNumber { get; set; }
    Property Value
    Type Description
    System.String

    The identifier number.

    IntegrationID

    Gets or sets the integration identifier in PSA/RMM/outside integration to filter companies by.

    Declaration
    [JsonProperty("id_in_integration")]
    public string IntegrationID { get; set; }
    Property Value
    Type Description
    System.String

    The integration identifier.

    Name

    Gets or sets the name to filter companies by.

    Declaration
    public string Name { get; set; }
    Property Value
    Type Description
    System.String

    The name.

    Page

    Gets or sets the current page of results.

    Declaration
    public int? Page { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    The page.

    PageSize

    Gets or sets the number of results to return from the Hudu API.

    Declaration
    public int? PageSize { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    The size of the page.

    PayloadType

    Declaration
    public string PayloadType { get; }
    Property Value
    Type Description
    System.String

    PhoneNumber

    Gets or sets the phone number to filter companies by.

    Declaration
    public string PhoneNumber { get; set; }
    Property Value
    Type Description
    System.String

    The phone number.

    State

    Gets or sets the state to filter companies by.

    Declaration
    public string State { get; set; }
    Property Value
    Type Description
    System.String

    The state.

    Website

    Gets or sets the website to filter companies by.

    Declaration
    public string Website { get; set; }
    Property Value
    Type Description
    System.String

    The website.

    Implements

    IParameters

    See Also

    IParameters
    © Dracon80. All rights reserved.