HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetExpirations

    Provides the paramaters to get a list of expirations from the Hudu endpoint api/v1/expirations

    Inheritance
    System.Object
    GetExpirations
    Implements
    IParameters
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class GetExpirations : IParameters

    Properties

    CompanyId

    Filter expirations by company_id.

    Declaration
    [JsonProperty("company_id")]
    public int? CompanyId { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    ExpirationType

    Filter expirations by expiration type (undeclared, domain, ssl_certificate, warranty, asset_field, article_expiration).

    Declaration
    [JsonProperty("expiration_type")]
    public string ExpirationType { get; set; }
    Property Value
    Type Description
    System.String

    Page

    Get this page of results when paging through results.

    Declaration
    [JsonProperty("page")]
    public int? Page { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    PageSize

    Number of results to return on each page.

    Declaration
    [JsonProperty("page_size")]
    public int? PageSize { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    PayloadType

    Declaration
    public string PayloadType { get; }
    Property Value
    Type Description
    System.String

    ResourceId

    Filter logs by resource id. Must be coupled with resource_type.

    Declaration
    [JsonProperty("resource_id")]
    public int? ResourceId { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    ResourceType

    Filter logs by resource type (Asset, AssetPassword, Company, Article, etc.). Must be coupled with resource_id.

    Declaration
    [JsonProperty("resource_type")]
    public int? ResourceType { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    Implements

    IParameters
    © Dracon80. All rights reserved.