HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetExpirationsBuilder

    Builder for the class GetExpirations

    Inheritance
    System.Object
    GetExpirationsBuilder
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class GetExpirationsBuilder

    Constructors

    GetExpirationsBuilder()

    Create a new instance for the GetExpirationsBuilder

    Declaration
    public GetExpirationsBuilder()

    Methods

    Build()

    Build a class of type GetExpirations with all the defined values

    Declaration
    public GetExpirations Build()
    Returns
    Type Description
    GetExpirations

    Returns a GetExpirations class

    Reset()

    Reset all properties' to the default value

    Declaration
    public GetExpirationsBuilder Reset()
    Returns
    Type Description
    GetExpirationsBuilder

    Returns the GetExpirationsBuilder with the properties reseted

    WithCompanyId(Int32)

    Set a value of type int?? for the property companyId

    Declaration
    public GetExpirationsBuilder WithCompanyId(int companyId)
    Parameters
    Type Name Description
    System.Int32 companyId

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetExpirationsBuilder

    Returns the GetExpirationsBuilder with the property companyId defined

    WithExpirationType(String)

    Set a value of type string for the property expirationType

    Declaration
    public GetExpirationsBuilder WithExpirationType(string expirationType)
    Parameters
    Type Name Description
    System.String expirationType

    A value of type string will the defined for the property

    Returns
    Type Description
    GetExpirationsBuilder

    Returns the GetExpirationsBuilder with the property expirationType defined

    WithPage(Int32)

    Set a value of type int?? for the property page

    Declaration
    public GetExpirationsBuilder WithPage(int page)
    Parameters
    Type Name Description
    System.Int32 page

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetExpirationsBuilder

    Returns the GetExpirationsBuilder with the property page defined

    WithPageSize(Int32)

    Set a value of type int?? for the property pageSize

    Declaration
    public GetExpirationsBuilder WithPageSize(int pageSize)
    Parameters
    Type Name Description
    System.Int32 pageSize

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetExpirationsBuilder

    Returns the GetExpirationsBuilder with the property pageSize defined

    WithResource(Int32, Int32)

    Set a value for the property resourceId and resourceType

    Declaration
    public GetExpirationsBuilder WithResource(int resourceId, int resourceType)
    Parameters
    Type Name Description
    System.Int32 resourceId

    A value of type int will the defined for the property

    System.Int32 resourceType

    A value of type int will the defined for the property

    Returns
    Type Description
    GetExpirationsBuilder

    Returns the GetExpirationsBuilder.

    © Dracon80. All rights reserved.