HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetFolders

    Provides the parameters to get a filtered list of Folders from the Hudu API endpoint api/v1/folders

    Inheritance
    System.Object
    GetFolders
    Implements
    IParameters
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class GetFolders : IParameters

    Properties

    CompanyId

    filter by company_id.

    Declaration
    [JsonProperty("company_id")]
    public int? CompanyId { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    Name

    Filter by folder name.

    Declaration
    [JsonProperty("name")]
    public string Name { get; set; }
    Property Value
    Type Description
    System.String

    Page

    Get this page of results when paging through results.

    Declaration
    [JsonProperty("page")]
    public int? Page { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    PageSize

    Number of results to return on each page.

    Declaration
    [JsonProperty("page_size")]
    public int? PageSize { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    PayloadType

    Declaration
    public string PayloadType { get; }
    Property Value
    Type Description
    System.String

    Implements

    IParameters
    © Dracon80. All rights reserved.