HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetFoldersBuilder

    Builder for the class GetFolders

    Inheritance
    System.Object
    GetFoldersBuilder
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class GetFoldersBuilder

    Constructors

    GetFoldersBuilder()

    Create a new instance for the GetFoldersBuilder

    Declaration
    public GetFoldersBuilder()

    Methods

    Build()

    Build a class of type GetFolders with all the defined values

    Declaration
    public GetFolders Build()
    Returns
    Type Description
    GetFolders

    Returns a GetFolders class

    Reset()

    Reset all properties' to the default value

    Declaration
    public GetFoldersBuilder Reset()
    Returns
    Type Description
    GetFoldersBuilder

    Returns the GetFoldersBuilder with the properties reseted

    WithCompanyId(Int32)

    Set a value of type int?? for the property companyId

    Declaration
    public GetFoldersBuilder WithCompanyId(int companyId)
    Parameters
    Type Name Description
    System.Int32 companyId

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetFoldersBuilder

    Returns the GetFoldersBuilder with the property companyId defined

    WithName(String)

    Set a value of type string for the property name

    Declaration
    public GetFoldersBuilder WithName(string name)
    Parameters
    Type Name Description
    System.String name

    A value of type string will the defined for the property

    Returns
    Type Description
    GetFoldersBuilder

    Returns the GetFoldersBuilder with the property name defined

    WithPage(Int32)

    Set a value of type int?? for the property page

    Declaration
    public GetFoldersBuilder WithPage(int page)
    Parameters
    Type Name Description
    System.Int32 page

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetFoldersBuilder

    Returns the GetFoldersBuilder with the property page defined

    WithPageSize(Int32)

    Set a value of type int?? for the property pageSize

    Declaration
    public GetFoldersBuilder WithPageSize(int pageSize)
    Parameters
    Type Name Description
    System.Int32 pageSize

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetFoldersBuilder

    Returns the GetFoldersBuilder with the property pageSize defined

    © Dracon80. All rights reserved.