Class GetMagicDash
Provides paramaters to filter a list of magic dash items when calling the endpoint api/v1/magic_dash
Inheritance
System.Object
GetMagicDash
Implements
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class GetMagicDash : IParameters
Properties
CompanyId
filter by company_id.
Declaration
[JsonProperty("company_id")]
public int? CompanyId { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Nullable<System.Int32> |
Page
Get this page of results when paging through results.
Declaration
[JsonProperty("page")]
public int? Page { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Nullable<System.Int32> |
PageSize
Number of results to return on each page.
Declaration
[JsonProperty("page_size")]
public int? PageSize { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Nullable<System.Int32> |
PayloadType
Declaration
public string PayloadType { get; }
Property Value
| Type | Description |
|---|---|
| System.String |
Title
Filter by title.
Declaration
[JsonProperty("title")]
public string Title { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |