HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetMagicDashBuilder

    Builder for the class GetMagicDash

    Inheritance
    System.Object
    GetMagicDashBuilder
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class GetMagicDashBuilder

    Constructors

    GetMagicDashBuilder()

    Create a new instance for the GetMagicDashBuilder

    Declaration
    public GetMagicDashBuilder()

    Methods

    Build()

    Build a class of type GetMagicDash with all the defined values

    Declaration
    public GetMagicDash Build()
    Returns
    Type Description
    GetMagicDash

    Returns a GetMagicDash class

    Reset()

    Reset all properties' to the default value

    Declaration
    public GetMagicDashBuilder Reset()
    Returns
    Type Description
    GetMagicDashBuilder

    Returns the GetMagicDashBuilder with the properties reseted

    WithCompanyId(Int32)

    Set a value of type int?? for the property companyId

    Declaration
    public GetMagicDashBuilder WithCompanyId(int companyId)
    Parameters
    Type Name Description
    System.Int32 companyId

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetMagicDashBuilder

    Returns the GetMagicDashBuilder with the property companyId defined

    WithPage(Int32)

    Set a value of type int?? for the property page

    Declaration
    public GetMagicDashBuilder WithPage(int page)
    Parameters
    Type Name Description
    System.Int32 page

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetMagicDashBuilder

    Returns the GetMagicDashBuilder with the property page defined

    WithPageSize(Int32)

    Set a value of type int?? for the property pageSize

    Declaration
    public GetMagicDashBuilder WithPageSize(int pageSize)
    Parameters
    Type Name Description
    System.Int32 pageSize

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetMagicDashBuilder

    Returns the GetMagicDashBuilder with the property pageSize defined

    WithTitle(String)

    Set a value of type string for the property title

    Declaration
    public GetMagicDashBuilder WithTitle(string title)
    Parameters
    Type Name Description
    System.String title

    A value of type string will the defined for the property

    Returns
    Type Description
    GetMagicDashBuilder

    Returns the GetMagicDashBuilder with the property title defined

    © Dracon80. All rights reserved.