HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetMatchers

    Provides the parameters to filter the list of matchers returned from the hudu endpoint api/v1/matchers

    Inheritance
    System.Object
    GetMatchers
    Implements
    IParameters
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class GetMatchers : IParameters

    Constructors

    GetMatchers(Int32)

    Inialize a new GetMatchers parameter list with the "integration_id assiged at creation as it is required.

    Declaration
    public GetMatchers(int integration_id)
    Parameters
    Type Name Description
    System.Int32 integration_id

    The integration identifier.

    Properties

    CompanyId

    Filter on company id

    Declaration
    [JsonProperty("company_id")]
    public int CompanyId { get; set; }
    Property Value
    Type Description
    System.Int32

    Identifier

    Filter by Identifier in the integration (if sync_id is not set). This is used if the id that the integration uses is a string.

    Declaration
    [JsonProperty("identifier")]
    public string Identifier { get; set; }
    Property Value
    Type Description
    System.String

    IntegrationId

    ID of the integration. Can be found in the URL when editing an integration

    Declaration
    [JsonProperty("integration_id")]
    public int IntegrationId { get; set; }
    Property Value
    Type Description
    System.Int32

    Matched

    Filter on whether the company already been matched

    Declaration
    [JsonProperty("matched")]
    public bool Matched { get; set; }
    Property Value
    Type Description
    System.Boolean

    Page

    get current page of results

    Declaration
    [JsonProperty("page")]
    public int Page { get; set; }
    Property Value
    Type Description
    System.Int32

    PageSize

    Number of results to return

    Declaration
    [JsonProperty("page_size")]
    public int PageSize { get; set; }
    Property Value
    Type Description
    System.Int32

    PayloadType

    Declaration
    public string PayloadType { get; }
    Property Value
    Type Description
    System.String

    SyncId

    Filter by ID of the record in the integration. This is used if the id that the integration uses is an integer.

    Declaration
    [JsonProperty("sync_id")]
    public string SyncId { get; set; }
    Property Value
    Type Description
    System.String

    Implements

    IParameters

    See Also

    IParameters
    © Dracon80. All rights reserved.