HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetProcedures

    Provides the paramters to filter the list of procedures returned from the hudu endpoint api/v1/procedures

    Inheritance
    System.Object
    GetProcedures
    Implements
    IParameters
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class GetProcedures : IParameters

    Properties

    CompanyId

    filter by company_id.

    Declaration
    [JsonProperty("company_id")]
    public int? CompanyId { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    Name

    filter by name of procedure.

    Declaration
    [JsonProperty("name")]
    public string Name { get; set; }
    Property Value
    Type Description
    System.String

    Page

    Get this page of results when paging through results.

    Declaration
    [JsonProperty("page")]
    public int? Page { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    PageSize

    Number of results to return on each page.

    Declaration
    [JsonProperty("page_size")]
    public int? PageSize { get; set; }
    Property Value
    Type Description
    System.Nullable<System.Int32>

    PayloadType

    Declaration
    public string PayloadType { get; }
    Property Value
    Type Description
    System.String

    Implements

    IParameters

    See Also

    IParameters
    © Dracon80. All rights reserved.