HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetProceduresBuilder

    Builder for the class GetProcedures

    Inheritance
    System.Object
    GetProceduresBuilder
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class GetProceduresBuilder

    Constructors

    GetProceduresBuilder()

    Create a new instance for the GetProceduresBuilder

    Declaration
    public GetProceduresBuilder()

    Methods

    Build()

    Build a class of type GetProcedures with all the defined values

    Declaration
    public GetProcedures Build()
    Returns
    Type Description
    GetProcedures

    Returns a GetProcedures class

    Reset()

    Reset all properties' to the default value

    Declaration
    public GetProceduresBuilder Reset()
    Returns
    Type Description
    GetProceduresBuilder

    Returns the GetProceduresBuilder with the properties reseted

    WithCompanyId(Int32)

    Set a value of type int for the property companyId

    Declaration
    public GetProceduresBuilder WithCompanyId(int companyId)
    Parameters
    Type Name Description
    System.Int32 companyId

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetProceduresBuilder

    Returns the GetProceduresBuilder with the property companyId defined

    WithName(String)

    Set a value of type string for the property name

    Declaration
    public GetProceduresBuilder WithName(string name)
    Parameters
    Type Name Description
    System.String name

    A value of type string will the defined for the property

    Returns
    Type Description
    GetProceduresBuilder

    Returns the GetProceduresBuilder with the property name defined

    WithPage(Int32)

    Set a value of type int for the property page

    Declaration
    public GetProceduresBuilder WithPage(int page)
    Parameters
    Type Name Description
    System.Int32 page

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetProceduresBuilder

    Returns the GetProceduresBuilder with the property page defined

    WithPageSize(Int32)

    Set a value of type int for the property pageSize

    Declaration
    public GetProceduresBuilder WithPageSize(int pageSize)
    Parameters
    Type Name Description
    System.Int32 pageSize

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetProceduresBuilder

    Returns the GetProceduresBuilder with the property pageSize defined

    © Dracon80. All rights reserved.