HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class GetRelationsBuilder

    Builder for the class GetRelations

    Inheritance
    System.Object
    GetRelationsBuilder
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class GetRelationsBuilder

    Constructors

    GetRelationsBuilder()

    Create a new instance for the GetRelationsBuilder

    Declaration
    public GetRelationsBuilder()

    Methods

    Build()

    Build a class of type GetRelations with all the defined values

    Declaration
    public GetRelations Build()
    Returns
    Type Description
    GetRelations

    Returns a GetRelations class

    Reset()

    Reset all properties' to the default value

    Declaration
    public GetRelationsBuilder Reset()
    Returns
    Type Description
    GetRelationsBuilder

    Returns the GetRelationsBuilder with the properties reseted

    WithPage(Int32)

    Set a value of type int for the property page

    Declaration
    public GetRelationsBuilder WithPage(int page)
    Parameters
    Type Name Description
    System.Int32 page

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetRelationsBuilder

    Returns the GetRelationsBuilder with the property page defined

    WithPageSize(Int32)

    Set a value of type int for the property pageSize

    Declaration
    public GetRelationsBuilder WithPageSize(int pageSize)
    Parameters
    Type Name Description
    System.Int32 pageSize

    A value of type int?? will the defined for the property

    Returns
    Type Description
    GetRelationsBuilder

    Returns the GetRelationsBuilder with the property pageSize defined

    © Dracon80. All rights reserved.