HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class ItemById

    A basic Parameter for all methods that can be called with a signle id parameter

    Inheritance
    System.Object
    ItemById
    AssetById
    Implements
    IParameters
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class ItemById : IParameters

    Constructors

    ItemById(Int32)

    Initializes a new instance of the class.

    Declaration
    public ItemById(int id)
    Parameters
    Type Name Description
    System.Int32 id

    Fields

    _id

    Declaration
    protected int _id
    Field Value
    Type Description
    System.Int32

    Properties

    ID

    Gets or sets the ID of the item to get from the hudu api.

    Declaration
    public int ID { get; set; }
    Property Value
    Type Description
    System.Int32

    PayloadType

    Declaration
    public string PayloadType { get; }
    Property Value
    Type Description
    System.String

    Implements

    IParameters
    © Dracon80. All rights reserved.