HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class UpdateArticle

    Provides all the properties needed to update an existing article using the hudu api api/v1/articles

    Inheritance
    System.Object
    Article
    UpdateArticle
    Implements
    IParameters
    Inherited Members
    Article.CompanyId
    Article.Content
    Article.EnableSharing
    Article.FolderId
    Article.Name
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class UpdateArticle : Article, IParameters

    Constructors

    UpdateArticle(Int32, String, String)

    Initializes a new instance of the UpdateArticle class with the required properties to update and existing article.

    Declaration
    public UpdateArticle(int id, string name, string content)
    Parameters
    Type Name Description
    System.Int32 id

    The Article identifier.

    System.String name

    The name of the article.

    System.String content

    The content to be displayed in the article.

    Properties

    Id

    Gets the identifier.

    Declaration
    [JsonIgnore]
    public int Id { get; }
    Property Value
    Type Description
    System.Int32

    The identifier.

    PayloadType

    Declaration
    public string PayloadType { get; }
    Property Value
    Type Description
    System.String

    Implements

    IParameters
    © Dracon80. All rights reserved.