HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class UpdateAssetLayout

    Provides all the properties required to call the endpoint api/v1/asset_layouts when updating an asset_layout

    Inheritance
    System.Object
    AssetLayout
    UpdateAssetLayout
    Implements
    IParameters
    Inherited Members
    AssetLayout._color
    AssetLayout._iconColor
    AssetLayout.Color
    AssetLayout.Fields
    AssetLayout.Icon
    AssetLayout.IconColor
    AssetLayout.IncludeComments
    AssetLayout.IncludeFiles
    AssetLayout.IncludePasswords
    AssetLayout.IncludePhotos
    AssetLayout.Name
    AssetLayout.PasswordTypes
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class UpdateAssetLayout : AssetLayout, IParameters

    Constructors

    UpdateAssetLayout(Int32, String, String, Color, Color, List<AssetLayoutField>)

    Initializes a new instance of the UpdateAssetLayout class with the required properties to update and existing asset_layout.

    Declaration
    public UpdateAssetLayout(int id, string name, string icon, Color color, Color iconColor, List<AssetLayoutField> assetLayoutFields)
    Parameters
    Type Name Description
    System.Int32 id

    The identifier of the existing asset_layout.

    System.String name

    The name of the asset_layout.

    System.String icon

    The icon to display.

    System.Drawing.Color color

    The background color.

    System.Drawing.Color iconColor

    Color of the icon.

    System.Collections.Generic.List<AssetLayoutField> assetLayoutFields

    The asset layout fields to be added to the existing layout. Do not provive existing field definitions

    Properties

    Active

    Gets or sets a value indicating whether this UpdateAssetLayout is active within hudu.

    Declaration
    public bool Active { get; set; }
    Property Value
    Type Description
    System.Boolean

    true if active; otherwise, false.

    Id

    Gets the identifier.

    Declaration
    [JsonIgnore]
    public int Id { get; }
    Property Value
    Type Description
    System.Int32

    The identifier.

    PayloadType

    Set the Payload wrapper for the json

    Declaration
    [JsonIgnore]
    public string PayloadType { get; }
    Property Value
    Type Description
    System.String

    Implements

    IParameters

    See Also

    AssetLayout
    © Dracon80. All rights reserved.