Class UpdateAssetLayoutBuilder
Inheritance
System.Object
UpdateAssetLayoutBuilder
Inherited Members
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class UpdateAssetLayoutBuilder : AssetLayoutBuilder<UpdateAssetLayout, UpdateAssetLayoutBuilder>
Constructors
UpdateAssetLayoutBuilder(Int32, String, String, Color, Color, List<AssetLayoutField>)
Initializes a new instance of the UpdateAssetLayoutBuilder class.
Declaration
public UpdateAssetLayoutBuilder(int id, string name, string icon, Color color, Color iconColor, List<AssetLayoutField> assetLayoutFields)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Int32 | id | The identifier of the existing asset_layout. |
| System.String | name | The name of the asset_layout. |
| System.String | icon | The icon to be used in the gui. |
| System.Drawing.Color | color | The color of the icon foreground. |
| System.Drawing.Color | iconColor | Color of the icon background. |
| System.Collections.Generic.List<AssetLayoutField> | assetLayoutFields | A list of asset layout fields that define the layout. |
Fields
_id
Declaration
protected int _id
Field Value
| Type | Description |
|---|---|
| System.Int32 |
Methods
Build()
Build a class of type CreateAssetLayouts with all the defined values
Declaration
public override UpdateAssetLayout Build()
Returns
| Type | Description |
|---|---|
| UpdateAssetLayout | Returns a CreateAssetLayouts class |
Overrides
HuduAPI.Endpoints.Parameters.AbstractBases.AssetLayoutBuilder<HuduAPI.Endpoints.Parameters.UpdateAssetLayout, HuduAPI.Endpoints.Parameters.UpdateAssetLayoutBuilder>.Build()