HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class UpdateFolder

    Provides all the properties required to update an existing Folder in hudu using the endpoint api/v1/folders

    Inheritance
    System.Object
    Folder
    UpdateFolder
    Implements
    IParameters
    Inherited Members
    Folder.CompanyId
    Folder.Description
    Folder.Icon
    Folder.Name
    Folder.ParentFolderId
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class UpdateFolder : Folder, IParameters

    Constructors

    UpdateFolder(Int32, String)

    Initializes a new instance of the UpdateFolder class with all the required properties to update and existing folder using the endpoint api/v1/folders.

    Declaration
    public UpdateFolder(int id, string name)
    Parameters
    Type Name Description
    System.Int32 id

    The identifier of the folder.

    System.String name

    The name that folder will be given.

    Properties

    Id

    Gets the identifier for this folder.

    Declaration
    public int Id { get; }
    Property Value
    Type Description
    System.Int32

    PayloadType

    Declaration
    public string PayloadType { get; }
    Property Value
    Type Description
    System.String

    Implements

    IParameters

    See Also

    Folder
    © Dracon80. All rights reserved.