Class UpdateFolderBuilder
This is a builder class to help build a new instance of a UpdateFolder object.
Inherited Members
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class UpdateFolderBuilder : FolderBuilder<UpdateFolder, UpdateFolderBuilder>
Constructors
UpdateFolderBuilder(Int32, String)
Initializes a new instance of the UpdateFolderBuilder class.
Declaration
public UpdateFolderBuilder(int id, string name)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Int32 | id | The identifier. |
| System.String | name | The name. |
Methods
Build()
Builds a new instance of type UpdateFolder with all the required properties to call the endpoint api/v1/folders.
Declaration
public override UpdateFolder Build()
Returns
| Type | Description |
|---|---|
| UpdateFolder | An instance of type UpdateFolder |
Overrides
HuduAPI.Endpoints.Parameters.AbstractBases.FolderBuilder<HuduAPI.Endpoints.Parameters.UpdateFolder, HuduAPI.Endpoints.Parameters.UpdateFolderBuilder>.Build()