HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class UpdateWebsite

    Provides all the properties requried to update a Website using the hudu api endpoint api/v1/websites

    Inheritance
    System.Object
    Website
    UpdateWebsite
    Implements
    IParameters
    Inherited Members
    Website.CompanyId
    Website.DisableDns
    Website.DisableSsl
    Website.DisableWhois
    Website.Name
    Website.Notes
    Website.Paused
    Namespace: HuduAPI.Endpoints.Parameters
    Assembly: HuduAPI.dll
    Syntax
    public class UpdateWebsite : Website, IParameters

    Constructors

    UpdateWebsite(Int32, String, Int32)

    Initializes a new instance of the UpdateWebsite class with the minimum required properties assigned.

    Declaration
    public UpdateWebsite(int id, string name, int companyId)
    Parameters
    Type Name Description
    System.Int32 id

    The identifier of the website to update.

    System.String name

    The name to set the website too.

    System.Int32 companyId

    The company identifier the website should be associated with.

    Properties

    Id

    Gets the identifier of the website to update.

    Declaration
    public int Id { get; }
    Property Value
    Type Description
    System.Int32

    PayloadType

    Declaration
    public string PayloadType { get; }
    Property Value
    Type Description
    System.String

    Implements

    IParameters

    See Also

    Website
    © Dracon80. All rights reserved.