Class UpdateWebsiteBuilder
This is a builder class to help build a new UpdateWebsite with all possible proerties to use the hudu endpoint api/v1/websites.
Inherited Members
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class UpdateWebsiteBuilder : WebsiteBuilder<UpdateWebsite, UpdateWebsiteBuilder>
Constructors
UpdateWebsiteBuilder(Int32, String, Int32)
Initializes a new instance of the UpdateWebsiteBuilder builder class.
Declaration
public UpdateWebsiteBuilder(int id, string name, int companyId)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Int32 | id | The identifier of the website. |
| System.String | name | The name to set the website too. |
| System.Int32 | companyId | The company identifier to associated the website with. |
Methods
Build()
Builds a new instance of type UpdateWebsite with all required properties initialised.
Declaration
public override UpdateWebsite Build()
Returns
| Type | Description |
|---|---|
| UpdateWebsite |
Overrides
HuduAPI.Endpoints.Parameters.AbstractBases.WebsiteBuilder<HuduAPI.Endpoints.Parameters.UpdateWebsite, HuduAPI.Endpoints.Parameters.UpdateWebsiteBuilder>.Build()