HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class ProceduresEndpoint

    Provides all the methods required to make calls to the Procedure endpoint of the Hudu API.

    Inheritance
    System.Object
    ProceduresEndpoint
    Namespace: HuduAPI.Endpoints
    Assembly: HuduAPI.dll
    Syntax
    public class ProceduresEndpoint

    Constructors

    ProceduresEndpoint(String, String)

    Initializes a new instance of the ProceduresEndpoint class with the required API Key and Hudu URL to make all calls.

    Declaration
    public ProceduresEndpoint(string huduAPIKey, string huduBaseURL)
    Parameters
    Type Name Description
    System.String huduAPIKey

    The hudu API key.

    System.String huduBaseURL

    The hudu base URL.

    Properties

    HuduAPIKey

    Gets or sets the hudu API key that will be used for all calls to this Endpoint.

    Declaration
    public string HuduAPIKey { get; set; }
    Property Value
    Type Description
    System.String

    The hudu API key.

    HuduBaseURL

    Gets or sets the hudu base URL that will be used for all calls to the Endpoint.

    Declaration
    public string HuduBaseURL { get; set; }
    Property Value
    Type Description
    System.String

    The hudu base URL.

    Methods

    Get(GetProcedures)

    Get a list of Procedure objects from the Hudu Endpoint

    Declaration
    public Procedures Get(GetProcedures parameters)
    Parameters
    Type Name Description
    GetProcedures parameters

    The parameters to use when making the call.

    Returns
    Type Description
    Procedures

    A Procedures objec that contains a list of Procedures found in hudu

    Get(ItemById)

    Gets a single Procedure object from the Hudu API using the supplied Item ID

    Declaration
    public Procedure Get(ItemById parameters)
    Parameters
    Type Name Description
    ItemById parameters

    The Procedure ID to use when making the call.

    Returns
    Type Description
    Procedure

    A Procedure object that represents the required Procedure in hudu

    See Also

    HuduAPI.Endpoints.IEndpoint
    © Dracon80. All rights reserved.