HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class WebsitesEndpoint

    Provides all the methods required to make calls to the Websites endpoint of the Hudu API.

    Inheritance
    System.Object
    WebsitesEndpoint
    Namespace: HuduAPI.Endpoints
    Assembly: HuduAPI.dll
    Syntax
    public class WebsitesEndpoint

    Constructors

    WebsitesEndpoint(String, String)

    Initializes a new instance of the class with the required API Key and Hudu URL to make all calls.

    Declaration
    public WebsitesEndpoint(string huduAPIKey, string huduBaseURL)
    Parameters
    Type Name Description
    System.String huduAPIKey

    The hudu API key.

    System.String huduBaseURL

    The hudu base URL.

    Properties

    HuduAPIKey

    Gets or sets the hudu API key that will be used for all calls to this Endpoint.

    Declaration
    public string HuduAPIKey { get; set; }
    Property Value
    Type Description
    System.String

    The hudu API key.

    HuduBaseURL

    Gets or sets the hudu base URL that will be used for all calls to the Endpoint.

    Declaration
    public string HuduBaseURL { get; set; }
    Property Value
    Type Description
    System.String

    The hudu base URL.

    Methods

    Create(CreateWebsite)

    Create a new Website in Hudu using the suppied parameters

    Declaration
    public Website Create(CreateWebsite parameters)
    Parameters
    Type Name Description
    CreateWebsite parameters

    The parameters to use when making the call.

    Returns
    Type Description
    Website

    An object of type TResult that represents the created object in hudu

    Delete(ItemById)

    Delete the specified Website from Hudu

    Declaration
    public void Delete(ItemById parameters)
    Parameters
    Type Name Description
    ItemById parameters

    The Website ID to use when making the call.

    Get(GetWebsites)

    Get a list of Website objects from the Hudu Endpoint

    Declaration
    public Websites Get(GetWebsites parameters)
    Parameters
    Type Name Description
    GetWebsites parameters

    The parameters to use when making the call.

    Returns
    Type Description
    Websites

    A Websites objec that contains a list of Websites found in hudu

    Get(ItemById)

    Gets a single Website object from the Hudu API using the supplied Item ID

    Declaration
    public Website Get(ItemById parameters)
    Parameters
    Type Name Description
    ItemById parameters

    The Website ID to use when making the call.

    Returns
    Type Description
    Website

    A Website object that represents the required Website in hudu

    Update(UpdateWebsite)

    Update an existing Website with the new details.

    Declaration
    public Website Update(UpdateWebsite parameters)
    Parameters
    Type Name Description
    UpdateWebsite parameters

    The parameters to use when making the call.

    Returns
    Type Description
    Website

    A Website object that represents the updated object in hudu

    See Also

    HuduAPI.Endpoints.IEndpoint
    © Dracon80. All rights reserved.