HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class Companies

    Companies represents the list of companies returned from a call to the Companies Endpoint.

    Inheritance
    System.Object
    Companies
    Implements
    IRecord
    Namespace: HuduAPI.Records
    Assembly: HuduAPI.dll
    Syntax
    public class Companies : IRecord
    Remarks

    Companies is a very simple object that contains a List of Company objects. Along with a Indexer to allow easy access to individual companies based on Company ID.

    Constructors

    Companies(IList<Company>)

    Initializes a new instance of the Companies class with the supplied list of Company objects.

    Declaration
    public Companies(IList<Company> companyList)
    Parameters
    Type Name Description
    IList<Company> companyList

    The list of Company objects.

    Properties

    CompanyList

    Declaration
    [JsonProperty("Companies")]
    public IList<Company> CompanyList { get; set; }
    Property Value
    Type Description
    IList<Company>

    Item[Int32]

    Gets the System.Nullable<T> with the a company ID of value index. If a company does not existing with this ID, then null is returend.

    Declaration
    public Company this[int id] { get; }
    Parameters
    Type Name Description
    System.Int32 id

    The company ID of the required company

    Property Value
    Type Description
    Company

    A Company with the company id of the value supplied to index.

    Implements

    IRecord
    © Dracon80. All rights reserved.