HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class Folders

    Represents a list of Folder objects returned from the Hudud Endpont

    Inheritance
    System.Object
    Folders
    Implements
    IRecord
    Namespace: HuduAPI.Records
    Assembly: HuduAPI.dll
    Syntax
    public class Folders : IRecord

    Properties

    FolderList

    Declaration
    [JsonProperty("folders")]
    public IList<Folder> FolderList { get; set; }
    Property Value
    Type Description
    IList<Folder>

    Item[Int32]

    Gets the System.Nullable<T> with the specified identifier. Will return null if no folder exists with the supplied ID

    Declaration
    public Folder this[int id] { get; }
    Parameters
    Type Name Description
    System.Int32 id

    The identifier.

    Property Value
    Type Description
    Folder

    The System.Nullable<T>.

    Implements

    IRecord

    See Also

    IRecord
    © Dracon80. All rights reserved.