HuduAPI Client HuduAPI Client
HuduAPI Client HuduAPI Client
DocFX

Search Results for

    Class Relations

    Represents a list of Relation objects that are returned from the Hudu API

    Inheritance
    System.Object
    Relations
    Implements
    IRecord
    Namespace: HuduAPI.Records
    Assembly: HuduAPI.dll
    Syntax
    public class Relations : IRecord

    Properties

    Item[Int32]

    Gets the System.Nullable<T> with the specified identifier. Returned null if no relation is found with the supplied ID

    Declaration
    public Relation this[int id] { get; }
    Parameters
    Type Name Description
    System.Int32 id

    The id of the relation to retrieve.

    Property Value
    Type Description
    Relation

    The Relation object request by ID.

    RelationsList

    Declaration
    [JsonProperty("relations")]
    public IList<Relation> RelationsList { get; set; }
    Property Value
    Type Description
    IList<Relation>

    Implements

    IRecord

    See Also

    IRecord
    © Dracon80. All rights reserved.