Namespace HuduAPI.Endpoints
Classes
ActivityLogsEndpoint
Provides all the methods required to make calls to the activity_logs endpoint of the Hudu API.
APIInfoEndpoint
Provides all the methods required to make calls to the api_info endpoint of the Hudu API.
ArticlesEndpoint
Provides all the methods required to make calls to the articles endpoint of the Hudu API.
AssetLayoutsEndpoint
Provides all the methods required to make calls to the asset_layout endpoint of the Hudu API.
AssetPasswordsEndpoint
Provides all the methods required to make calls to the asset_passwords endpoint of the Hudu API.
AssetsEndpoint
Provides all the methods required to make calls to the Asset endpoint of the Hudu API.
CompaniesEndpoint
Provides all the methods required to make calls to the company endpoint of the Hudu API.
FoldersEndpoint
Provides all the methods required to make calls to the folder endpoint of the Hudu API.
MagicDashEndpoint
Provides all the methods required to make calls to the MagicDash endpoint of the Hudu API.
MatchersEndpoint
Provides all the methods required to make calls to the Matchers endpoint of the Hudu API.
ProceduresEndpoint
Provides all the methods required to make calls to the Procedure endpoint of the Hudu API.
RelationEndpoint
Provides all the methods required to make calls to the Relation endpoint of the Hudu API.
WebsitesEndpoint
Provides all the methods required to make calls to the Websites endpoint of the Hudu API.