Class ActivityLogsEndpoint
Provides all the methods required to make calls to the activity_logs endpoint of the Hudu API.
Inheritance
Namespace: HuduAPI.Endpoints
Assembly: HuduAPI.dll
Syntax
public class ActivityLogsEndpoint
Remarks
The activity_logs endpoint is a read only interface that retrives a list of acticity logs representing user activity on the Hudu server. Filtering can be applied to help narrow down the returned ActivityLog Objects.
Constructors
ActivityLogsEndpoint(String, String)
Initializes a new instance of the ActivityLogsEndpoint class with the requried API Key and the base URL of the Hudu Server.
Declaration
public ActivityLogsEndpoint(string huduAPIKey, string huduBaseURL)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | huduAPIKey | The hudu API key. |
| System.String | huduBaseURL | The hudu base URL. |
Properties
HuduAPIKey
Gets or sets the hudu API key that will be used for all calls to this Endpoint.
Declaration
public string HuduAPIKey { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String | The hudu API key. |
HuduBaseURL
Gets or sets the hudu base URL that will be used for all calls to the Endpoint.
Declaration
public string HuduBaseURL { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String | The hudu base URL. |
Methods
Get(GetActivityLogs)
Will make a call to the Hudu API activity_logs endpoint.
Declaration
public ActivityLogs Get(GetActivityLogs parameters)
Parameters
| Type | Name | Description |
|---|---|---|
| GetActivityLogs | parameters | The parameters to be used for filtering the activity logs that will be returned. |
Returns
| Type | Description |
|---|---|
| ActivityLogs | Returns an ActivityLogs object with all the activities that matached the filtering paramaters. |
Remarks
It is acceptable to cal the method with no paramaters, in which case all activity logs will be returnedd