Class MagicDashEndpoint
Provides all the methods required to make calls to the MagicDash endpoint of the Hudu API.
Inheritance
Namespace: HuduAPI.Endpoints
Assembly: HuduAPI.dll
Syntax
public class MagicDashEndpoint
Constructors
MagicDashEndpoint(String, String)
Initializes a new instance of the MagicDashEndpoint class with the required API Key and Hudu URL to make all calls.
Declaration
public MagicDashEndpoint(string huduAPIKey, string huduBaseURL)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | huduAPIKey | The hudu API key. |
| System.String | huduBaseURL | The hudu base URL. |
Properties
HuduAPIKey
Gets or sets the hudu API key that will be used for all calls to this Endpoint.
Declaration
public string HuduAPIKey { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String | The hudu API key. |
HuduBaseURL
Gets or sets the hudu base URL that will be used for all calls to the Endpoint.
Declaration
public string HuduBaseURL { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String | The hudu base URL. |
Methods
Create(CreateMagicDash)
Creates a new, or updates and existing MagicDash item in Hudu
Declaration
public MagicDash Create(CreateMagicDash parameters)
Parameters
| Type | Name | Description |
|---|---|---|
| CreateMagicDash | parameters | The required MagicDash parameters to use when making the call. |
Returns
| Type | Description |
|---|---|
| MagicDash | A MagicDash object that represents the created dash in hudu |
Delete(ItemById)
Delete the specified MagicDash from Hudu
Declaration
public void Delete(ItemById parameters)
Parameters
| Type | Name | Description |
|---|---|---|
| ItemById | parameters | The MagicDash ID to use when making the call. |
Get(GetMagicDash)
Get a list of MagicDash objects from the Hudu Endpoint
Declaration
public MagicDashes Get(GetMagicDash parameters)
Parameters
| Type | Name | Description |
|---|---|---|
| GetMagicDash | parameters | The parameters to use when making the call. |
Returns
| Type | Description |
|---|---|
| MagicDashes | A MagicDashs object that contains a list of MagicDashs found in hudu |