Namespace HuduAPI.Endpoints.Parameters
Classes
AssetById
Provides the paramaters to target a single Asset from the Hudu endpoint. This is needed because the Call tot he asset endpoint required additional information such as the company ID.
AssetLayoutField
Defines the attributes of an Asset Layout Field. All requried properties are included in the constructor of the class. All other properties are optional when making a call to the endpoint api/v1/asset_layouts
AssetLayoutFieldBuilder
Builder for the class AssetLayoutField
CreateArticle
Provides the paramaters used to create a new article when calling the endpoint api/v1/articles
CreateArticleBuilder
Builder for the class CreateArticle
CreateAsset
Provides all the properties that can be used to create a new asset using the hudu endpoint api/v1/companies/:company_id/assets
CreateAssetBuilder
Builder class to help build a new CreateAsset paramater object.
CreateAssetLayout
Defines the properties to be used when creating a new AssetLayout in Hudu using the endpoint api/v1/asset_layouts
CreateAssetLayoutBuilder
This builder allows for easy creation of a new CreateAssetLayout instance used when calling api/v1/asset_layouts to create a new asset_layout.
CreateAssetPassword
Provides all the properties that define a new asset_password to be created in hudu using the endpoint api/v1/asset_passwords
CreateAssetPasswordBuilder
Builder for the class CreateAssetPassword
CreateCompany
Provides all the properties required to create a new company using the hudu endpoint api/v1/companies
CreateCompanyBuilder
Builder for the class CreateCompany
CreateFolder
Provides all the properties needed to create a new folder using the hudu endpoint api/v1/folders
CreateFolderBuilder
Builder for the class CreateFolder
CreateMagicDash
Provides all the properties used to create a new, or update an existing magic_dash item using the endpoint api/v1/magic_dash
CreateMagicDashBuilder
Builder for the class CreateMagicDash
CreateRelation
Provides all the properties required to create a new relationship using the endpoint api/v1/relations
CreateRelationBuilder
Builder for the class CreateRelation
CreateWebsite
Provides all the properties required to create a new website using the hudu endpoint api/v1/websites
CreateWebsiteBuilder
Builder for the class CreateWebsite
GetActivityLogs
A parameter object for the hudu endpoint api/v1/activity_logs. The values provided to the fields or constructor help narrow down the returned results of the get query. All fields default to null, which is acceptable by the Hudu API.
GetActivityLogsBuilder
Builder for the class GetActivityLogs
GetArticles
Paramaters to get articles from the Hudu API endpoint /api/v1/articles
GetArticlesBuilder
Builder for the class GetArticles
GetAssetLayouts
Paramaters to get asset_layouts from the Hudu API endpoint /api/v1/asset_layouts
GetAssetLayoutsBuilder
Builder for the class GetAssetLayouts
GetAssetPasswords
Get a list of AssetPasswords from the Hudu API endpoint api/v1/asset_passwords using the supplied paramaters to narrow down the results.
GetAssetPasswordsBuilder
Builder for the class GetAssetPasswords
GetAssets
Provides all the filters that can be used when calling a the get method on api/v1/assets
GetAssetsBuilder
Builder for the class GetAssets
GetCompanies
Paramaters to get a list of companies from hudu
GetCompaniesBuilder
GetExpirations
Provides the paramaters to get a list of expirations from the Hudu endpoint api/v1/expirations
GetExpirationsBuilder
Builder for the class GetExpirations
GetFolders
Provides the parameters to get a filtered list of Folders from the Hudu API endpoint api/v1/folders
GetFoldersBuilder
Builder for the class GetFolders
GetMagicDash
Provides paramaters to filter a list of magic dash items when calling the endpoint api/v1/magic_dash
GetMagicDashBuilder
Builder for the class GetMagicDash
GetMatchers
Provides the parameters to filter the list of matchers returned from the hudu endpoint api/v1/matchers
GetMatchersBuilder
Builder for the class GetMatchers
GetProcedures
Provides the paramters to filter the list of procedures returned from the hudu endpoint api/v1/procedures
GetProceduresBuilder
Builder for the class GetProcedures
GetRelations
Provides the parameters to get a list of relations
GetRelationsBuilder
Builder for the class GetRelations
GetWebsites
Provides the parameters to filter the list of Websites returned from the hudu endpoint api/v1/websites
GetWebsitesBuilder
Builder for the class GetWebsites
ItemById
A basic Parameter for all methods that can be called with a signle id parameter
UpdateArticle
Provides all the properties needed to update an existing article using the hudu api api/v1/articles
UpdateArticleBuilder
Builder for the class UpdateArticle
UpdateAsset
Provides all the properties to update an existing Asset in hudu.
UpdateAssetBuilder
Builder class to help build a new UpdateAsset paramater object.
UpdateAssetLayout
Provides all the properties required to call the endpoint api/v1/asset_layouts when updating an asset_layout
UpdateAssetLayoutBuilder
UpdateAssetPassword
Provides all properties required to update an existing asset_password using the api/v1/asset_passwords/ endpoint
UpdateAssetPasswordBuilder
Builder class for UpdateAssetPassword. Used to create a complete paramater object.
UpdateCompany
Provides all the properties required to call the hudu endpoint api/v1/companies and update an existing company.
UpdateCompanyBuilder
A builder class to help build new UpdateCompany objects with the required properties to call the hudu endpoint api/v1/companies
UpdateFolder
Provides all the properties required to update an existing Folder in hudu using the endpoint api/v1/folders
UpdateFolderBuilder
This is a builder class to help build a new instance of a UpdateFolder object.
UpdateMatcher
UpdateMatcherBuilder
Builder for the class UpdateMatcher
UpdateWebsite
Provides all the properties requried to update a Website using the hudu api endpoint api/v1/websites
UpdateWebsiteBuilder
This is a builder class to help build a new UpdateWebsite with all possible proerties to use the hudu endpoint api/v1/websites.
Interfaces
IParameters
All endpoint parameters must implement this interface to allow extension methods related to paramters.
Enums
AssetLayoutFieldType
The AssetLayout Field Types that can be created