Class Asset
An asbstract class providing all the common properties to call the hudu endpoint api/v1/companies/:company_id/assets
Namespace: HuduAPI.Endpoints.Parameters.AbstractBases
Assembly: HuduAPI.dll
Syntax
public abstract class Asset
Constructors
Asset(Int32, Int32, String)
Absrtact constructor to build the shared minimum properties.
Declaration
public Asset(int companyId, int assetLayoutId, string name)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Int32 | companyId | The company identifier. |
| System.Int32 | assetLayoutId | The asset layout identifier. |
| System.String | name | The name. |
Properties
AssetLayoutId
Gets the asset layout identifier this asset is assocatiated with.
Declaration
[JsonProperty("asset_layout_id")]
public int AssetLayoutId { get; protected set; }
Property Value
| Type | Description |
|---|---|
| System.Int32 |
CompanyId
Gets the company identifier the asset should be associated with.
Declaration
[JsonProperty("company_id")]
[JsonIgnore]
public int CompanyId { get; protected set; }
Property Value
| Type | Description |
|---|---|
| System.Int32 |
CustomFields
Gets or sets the custom fields dictionary. The key must be the lable of the asset_type field in lowercase.
Declaration
[JsonProperty("custom_fields")]
public AssetCustomField CustomFields { get; set; }
Property Value
| Type | Description |
|---|---|
| AssetCustomField |
Name
Gets the name of the asset.
Declaration
[JsonProperty("name")]
public string Name { get; protected set; }
Property Value
| Type | Description |
|---|---|
| System.String |
PrimaryMail
Gets or sets the primary mail.
Declaration
[JsonProperty("primary_mail")]
public string PrimaryMail { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
PrimaryManufacturer
Gets or sets the primary manufacturer.
Declaration
[JsonProperty("primary_manufacturer")]
public string PrimaryManufacturer { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
PrimaryModel
Gets or sets the primary model.
Declaration
[JsonProperty("primary_model")]
public string PrimaryModel { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
PrimarySerial
Gets or sets the primary serial.
Declaration
[JsonProperty("primary_serial")]
public string PrimarySerial { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |