Class AssetPassword
Provides all the properties that define an asset_password to be used when calling the endpoint api/v1/asset_passwords
Namespace: HuduAPI.Endpoints.Parameters.AbstractBases
Assembly: HuduAPI.dll
Syntax
public abstract class AssetPassword
Properties
CompanyId
Gets or sets the company identifier to associate the password with.
Declaration
[JsonProperty("company_id")]
public int CompanyId { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Int32 |
Description
A short description of the password
Declaration
[JsonProperty("description")]
public string Description { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
InPortal
Should the password be shown in the user portal
Declaration
[JsonProperty("in_portal")]
public bool InPortal { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Boolean |
Name
The name of the password
Declaration
[JsonProperty("name")]
public string Name { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
OtpSecret
The OTP secret code to generate the OTP
Declaration
[JsonProperty("otp_secret")]
public string OtpSecret { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
Password
The password in plain text
Declaration
[JsonProperty("password")]
public string Password { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
PasswordableId
No idea
Declaration
[JsonProperty("passwordable_id")]
public int? PasswordableId { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Nullable<System.Int32> |
PasswordableType
No idea
Declaration
[JsonProperty("passwordable_type")]
public string PasswordableType { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
PasswordFolderId
The folder ID the password should be stored in
Declaration
[JsonProperty("password_folder_id")]
public int? PasswordFolderId { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Nullable<System.Int32> |
PasswordType
The type of password
Declaration
[JsonProperty("password_type")]
public string PasswordType { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
Url
The URL associated with the password
Declaration
[JsonProperty("url")]
public string Url { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
Username
The username associated with the password
Declaration
[JsonProperty("username")]
public string Username { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |