Class Company
Provides all the common properties required to create or update a company using the hudu endpoint api/v1/companies
Namespace: HuduAPI.Endpoints.Parameters.AbstractBases
Assembly: HuduAPI.dll
Syntax
public abstract class Company
Properties
AddressLine1
Gets or sets the address line 1 of the company address.
Declaration
[JsonProperty("address_line_1")]
public string AddressLine1 { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
AddressLine2
Gets or sets the address line 2 of the company address.
Declaration
[JsonProperty("address_line_2")]
public string AddressLine2 { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
City
Gets or sets the city of the company address.
Declaration
[JsonProperty("city")]
public string City { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
CompanyType
Gets or sets the type of the company.
Declaration
[JsonProperty("company_type")]
public string CompanyType { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
CountryName
Gets or sets the country of the company address.
Declaration
[JsonProperty("country_name")]
public string CountryName { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
FaxNumber
Gets or sets the fax number of the company.
Declaration
[JsonProperty("fax_number")]
public string FaxNumber { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
IdNumber
Gets or sets an identifier number associated with the company.
Declaration
[JsonProperty("id_number")]
public string IdNumber { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
Name
Gets the name of the new company.
Declaration
[JsonProperty("name")]
public string Name { get; }
Property Value
| Type | Description |
|---|---|
| System.String |
Nickname
Gets or sets the nickname of the company.
Declaration
[JsonProperty("nickname")]
public string Nickname { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
Notes
Gets or sets the notes about the company.
Declaration
[JsonProperty("notes")]
public string Notes { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
ParentCompanyId
Gets or sets the parent company identifier for this company.
Declaration
[JsonProperty("parent_company_id")]
public int? ParentCompanyId { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Nullable<System.Int32> |
PhoneNumber
Gets or sets the phone number of the company.
Declaration
[JsonProperty("phone_number")]
public string PhoneNumber { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
State
Gets or sets the state of the company address.
Declaration
[JsonProperty("state")]
public string State { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
Website
Gets or sets the website of the company.
Declaration
[JsonProperty("website")]
public string Website { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
Zip
Gets or sets the zip of the company address.
Declaration
[JsonProperty("zip")]
public string Zip { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |