Class Folder
Provides all the properties needed to create a new folder using the hudu endpoint api/v1/folders
Namespace: HuduAPI.Endpoints.Parameters.AbstractBases
Assembly: HuduAPI.dll
Syntax
public abstract class Folder
Properties
CompanyId
Gets or sets the company identifier to associate this folder with.
Declaration
[JsonProperty("company_id")]
public int? CompanyId { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Nullable<System.Int32> |
Description
Gets or sets the description.
Declaration
[JsonProperty("description")]
public string Description { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
Icon
Gets or Sets the Icon class name, example: “fas fa-home”
Declaration
[JsonProperty("icon")]
public string Icon { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
Name
Gets or sets the name of the folder.
Declaration
[JsonProperty("name")]
public string Name { get; }
Property Value
| Type | Description |
|---|---|
| System.String |
ParentFolderId
Gets or sets the folder ID to associate this folder with a parent folder.
Declaration
[JsonProperty("parent_folder_id")]
public int? ParentFolderId { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Nullable<System.Int32> |