Class AssetById
Provides the paramaters to target a single Asset from the Hudu endpoint. This is needed because the Call tot he asset endpoint required additional information such as the company ID.
Implements
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class AssetById : ItemById, IParameters
Constructors
AssetById(Int32, Int32)
Initializes a new instance of the AssetById class.
Declaration
public AssetById(int id, int companyId)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Int32 | id | The identifier. |
| System.Int32 | companyId | The company identifier. |
Properties
CompanyId
Gets the company identifier.
Declaration
public int CompanyId { get; }
Property Value
| Type | Description |
|---|---|
| System.Int32 | The company identifier. |