Class AssetLayoutFieldBuilder
Builder for the class AssetLayoutField
Inheritance
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class AssetLayoutFieldBuilder
Constructors
AssetLayoutFieldBuilder(String, AssetLayoutFieldType)
Create a new instance for the AssetLayoutFieldBuilder
Declaration
public AssetLayoutFieldBuilder(string label, AssetLayoutFieldType fieldType)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | label | |
| AssetLayoutFieldType | fieldType |
Methods
Build()
Build a class of type AssetLayoutField with all the defined values
Declaration
public AssetLayoutField Build()
Returns
| Type | Description |
|---|---|
| AssetLayoutField | Returns a AssetLayoutField class |
Reset(String, AssetLayoutFieldType)
Reset all properties' to the default value
Declaration
public AssetLayoutFieldBuilder Reset(string label, AssetLayoutFieldType fieldType)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | label | |
| AssetLayoutFieldType | fieldType |
Returns
| Type | Description |
|---|---|
| AssetLayoutFieldBuilder | Returns the AssetLayoutFieldBuilder with the properties reseted |
WithExpiration(Boolean)
Set a value of type bool for the property expiration
Declaration
public AssetLayoutFieldBuilder WithExpiration(bool expiration)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Boolean | expiration | A value of type |
Returns
| Type | Description |
|---|---|
| AssetLayoutFieldBuilder | Returns the AssetLayoutFieldBuilder with the
property |
WithFieldtype(AssetLayoutFieldType)
Set a value of type AssetLayoutFieldType for the property
fieldtype
Declaration
public AssetLayoutFieldBuilder WithFieldtype(AssetLayoutFieldType fieldtype)
Parameters
| Type | Name | Description |
|---|---|---|
| AssetLayoutFieldType | fieldtype | A value of type |
Returns
| Type | Description |
|---|---|
| AssetLayoutFieldBuilder | Returns the AssetLayoutFieldBuilder with the
property |
WithFieldType(AssetLayoutFieldType)
Set a value of type AssetLayoutFieldType for the property
fieldType
Declaration
public AssetLayoutFieldBuilder WithFieldType(AssetLayoutFieldType fieldType)
Parameters
| Type | Name | Description |
|---|---|---|
| AssetLayoutFieldType | fieldType | A value of type |
Returns
| Type | Description |
|---|---|
| AssetLayoutFieldBuilder | Returns the AssetLayoutFieldBuilder with the
property |
WithHint(String)
Set a value of type string for the property hint
Declaration
public AssetLayoutFieldBuilder WithHint(string hint)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | hint | A value of type |
Returns
| Type | Description |
|---|---|
| AssetLayoutFieldBuilder | Returns the AssetLayoutFieldBuilder with the
property |
WithLabel(String)
Set a value of type string for the property label
Declaration
public AssetLayoutFieldBuilder WithLabel(string label)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | label | A value of type |
Returns
| Type | Description |
|---|---|
| AssetLayoutFieldBuilder | Returns the AssetLayoutFieldBuilder with the
property |
WithLinkableId(Nullable<Int32>)
Set a value of type int?? for the property linkableId
Declaration
public AssetLayoutFieldBuilder WithLinkableId(int? linkableId)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Nullable<System.Int32> | linkableId | A value of type |
Returns
| Type | Description |
|---|---|
| AssetLayoutFieldBuilder | Returns the AssetLayoutFieldBuilder with the
property |
WithMax(Nullable<Int32>)
Set a value of type int?? for the property max
Declaration
public AssetLayoutFieldBuilder WithMax(int? max)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Nullable<System.Int32> | max | A value of type |
Returns
| Type | Description |
|---|---|
| AssetLayoutFieldBuilder | Returns the AssetLayoutFieldBuilder with the
property |
WithMin(Nullable<Int32>)
Set a value of type int?? for the property min
Declaration
public AssetLayoutFieldBuilder WithMin(int? min)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Nullable<System.Int32> | min | A value of type |
Returns
| Type | Description |
|---|---|
| AssetLayoutFieldBuilder | Returns the AssetLayoutFieldBuilder with the
property |
WithOptions(String)
Set a value of type string for the property options
Declaration
public AssetLayoutFieldBuilder WithOptions(string options)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | options | A value of type |
Returns
| Type | Description |
|---|---|
| AssetLayoutFieldBuilder | Returns the AssetLayoutFieldBuilder with the
property |
WithPosition(Int32)
Set a value of type int?? for the property position
Declaration
public AssetLayoutFieldBuilder WithPosition(int position)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Int32 | position | A value of type |
Returns
| Type | Description |
|---|---|
| AssetLayoutFieldBuilder | Returns the AssetLayoutFieldBuilder with the
property |
WithRequired(Boolean)
Set a value of type bool for the property required
Declaration
public AssetLayoutFieldBuilder WithRequired(bool required)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Boolean | required | A value of type |
Returns
| Type | Description |
|---|---|
| AssetLayoutFieldBuilder | Returns the AssetLayoutFieldBuilder with the
property |
WithShowInList(Boolean)
Set a value of type bool for the property showInList
Declaration
public AssetLayoutFieldBuilder WithShowInList(bool showInList)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Boolean | showInList | A value of type |
Returns
| Type | Description |
|---|---|
| AssetLayoutFieldBuilder | Returns the AssetLayoutFieldBuilder with the
property |