Class CreateArticle
Provides the paramaters used to create a new article when calling the endpoint api/v1/articles
Implements
Inherited Members
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class CreateArticle : Article, IParameters
Constructors
CreateArticle(String, String)
Initializes a new instance of the CreateArticle class with the two required fields for the endpoint API.
Declaration
public CreateArticle(string name, string content)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | name | The name of the article. |
| System.String | content | The content to be displayed in the article. |
Properties
PayloadType
Declaration
public string PayloadType { get; }
Property Value
| Type | Description |
|---|---|
| System.String |