Class CreateAsset
Provides all the properties that can be used to create a new asset using the hudu endpoint api/v1/companies/:company_id/assets
Implements
Inherited Members
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class CreateAsset : Asset, IParameters
Constructors
CreateAsset(Int32, Int32, String)
Initializes a new instance of the CreateAsset class.
Declaration
public CreateAsset(int companyId, int assetLayoutId, string name)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Int32 | companyId | The company identifier. |
| System.Int32 | assetLayoutId | The asset layout identifier. |
| System.String | name | The name. |
Properties
PayloadType
Declaration
[JsonIgnore]
public string PayloadType { get; }
Property Value
| Type | Description |
|---|---|
| System.String |