Class CreateAssetLayout
Defines the properties to be used when creating a new AssetLayout in Hudu using the endpoint api/v1/asset_layouts
Implements
Inherited Members
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class CreateAssetLayout : AssetLayout, IParameters
Constructors
CreateAssetLayout(String, String, Color, Color, List<AssetLayoutField>)
Initializes a new instance of the CreateAssetLayout class with all required properties to call the hudu endpoint api/v1/asset_layouts.
Declaration
public CreateAssetLayout(string name, string icon, Color color, Color iconColor, List<AssetLayoutField> assetLayoutFields)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | name | The name of the new asset_layout. |
| System.String | icon | The Icon class name, example: “fas fa-home”. |
| System.Drawing.Color | color | The Color for background color. |
| System.Drawing.Color | iconColor | Color of the icon foreground. |
| List<AssetLayoutField> | assetLayoutFields | The asset layout fields. |
Remarks
All other properties of the class are optional properties that can safely be left blank and still be able to call the endpoint
Properties
PayloadType
Declaration
public string PayloadType { get; }
Property Value
| Type | Description |
|---|---|
| System.String |