Class CreateMagicDashBuilder
Builder for the class CreateMagicDash
Inheritance
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class CreateMagicDashBuilder
Constructors
CreateMagicDashBuilder(String, String, String)
Create a new instance for the CreateMagicDashBuilder
Declaration
public CreateMagicDashBuilder(string title, string companyName, string message)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | title | |
| System.String | companyName | |
| System.String | message |
Methods
Build()
Build a class of type CreateMagicDash with all the defined values
Declaration
public CreateMagicDash Build()
Returns
| Type | Description |
|---|---|
| CreateMagicDash | Returns a CreateMagicDash class |
WithContent(String)
Set a value of type string for the property content
Declaration
public CreateMagicDashBuilder WithContent(string content)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | content | A value of type |
Returns
| Type | Description |
|---|---|
| CreateMagicDashBuilder | Returns the CreateMagicDashBuilder with the
property |
WithContentLink(String)
Set a value of type string for the property contentLink
Declaration
public CreateMagicDashBuilder WithContentLink(string contentLink)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | contentLink | A value of type |
Returns
| Type | Description |
|---|---|
| CreateMagicDashBuilder | Returns the CreateMagicDashBuilder with the
property |
WithIcon(String)
Set a value of type string for the property icon
Declaration
public CreateMagicDashBuilder WithIcon(string icon)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | icon | A value of type |
Returns
| Type | Description |
|---|---|
| CreateMagicDashBuilder | Returns the CreateMagicDashBuilder with the
property |
WithImageUrl(String)
Set a value of type string for the property imageUrl
Declaration
public CreateMagicDashBuilder WithImageUrl(string imageUrl)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | imageUrl | A value of type |
Returns
| Type | Description |
|---|---|
| CreateMagicDashBuilder | Returns the CreateMagicDashBuilder with the
property |
WithShade(String)
Set a value of type string for the property shade
Declaration
public CreateMagicDashBuilder WithShade(string shade)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | shade | Options are to use a null string, success, or danger (not case sensitive). Setting to any other string value will result in a blank shade. |
Returns
| Type | Description |
|---|---|
| CreateMagicDashBuilder | Returns the CreateMagicDashBuilder with the
property |