Class CreateRelationBuilder
Builder for the class CreateRelation
Inheritance
System.Object
CreateRelationBuilder
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class CreateRelationBuilder
Constructors
CreateRelationBuilder(String, Int32, String, Int32)
Create a new instance for the CreateRelationBuilder
Declaration
public CreateRelationBuilder(string toableType, int toableId, string fromableType, int fromableId)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | toableType | The type of the TO relation. |
| System.Int32 | toableId | The ID of the TO relation. |
| System.String | fromableType | The type of the FROM relation. |
| System.Int32 | fromableId | The ID of the FROM relation. |
Methods
Build()
Build a class of type CreateRelation with all the defined values
Declaration
public CreateRelation Build()
Returns
| Type | Description |
|---|---|
| CreateRelation | Returns a CreateRelation class |
WithDescription(String)
Set a value of type string for the property description
Declaration
public CreateRelationBuilder WithDescription(string description)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | description | A value of type |
Returns
| Type | Description |
|---|---|
| CreateRelationBuilder | Returns the CreateRelationBuilder with the
property |
WithIsInverse(Boolean)
Set a value of type bool for the property isInverse
Declaration
public CreateRelationBuilder WithIsInverse(bool isInverse)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Boolean | isInverse | A value of type |
Returns
| Type | Description |
|---|---|
| CreateRelationBuilder | Returns the CreateRelationBuilder with the
property |