Class GetAssetPasswords
Get a list of AssetPasswords from the Hudu API endpoint api/v1/asset_passwords using the supplied paramaters to narrow down the results.
Inheritance
System.Object
GetAssetPasswords
Implements
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class GetAssetPasswords : IParameters
Properties
CompanyID
filter by company_id.
Declaration
[JsonProperty("company_id")]
public int? CompanyID { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Nullable<System.Int32> |
Name
filter by name of password.
Declaration
[JsonProperty("name")]
public string Name { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
Page
The gage number when paging through the results.
Declaration
[JsonProperty("page")]
public int? Page { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Nullable<System.Int32> |
PageSize
Gets or sets the number of results to show on each page.
Declaration
[JsonProperty("page_size")]
public int? PageSize { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Nullable<System.Int32> |
PayloadType
Declaration
public string PayloadType { get; }
Property Value
| Type | Description |
|---|---|
| System.String |