Interface IParameters
All endpoint parameters must implement this interface to allow extension methods related to paramters.
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public interface IParameters
Properties
PayloadType
Some of the Hudu paramaters need to have a payload wrapper in the Json, some do not. This allows an implementing class to define if there should be a wrapper.
Declaration
string PayloadType { get; }
Property Value
| Type | Description |
|---|---|
| System.String |