Class ItemById
A basic Parameter for all methods that can be called with a signle id parameter
Inheritance
System.Object
ItemById
Assembly: HuduAPI.dll
Syntax
public class ItemById : IParameters
Constructors
ItemById(Int32)
Initializes a new instance of the class.
Declaration
Parameters
| Type |
Name |
Description |
| System.Int32 |
id |
|
Fields
_id
Declaration
Field Value
| Type |
Description |
| System.Int32 |
|
Properties
ID
Gets or sets the ID of the item to get from the hudu api.
Declaration
public int ID { get; set; }
Property Value
| Type |
Description |
| System.Int32 |
|
PayloadType
Declaration
public string PayloadType { get; }
Property Value
| Type |
Description |
| System.String |
|
Implements