Class UpdateArticle
Provides all the properties needed to update an existing article using the hudu api api/v1/articles
Implements
Inherited Members
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class UpdateArticle : Article, IParameters
Constructors
UpdateArticle(Int32, String, String)
Initializes a new instance of the UpdateArticle class with the required properties to update and existing article.
Declaration
public UpdateArticle(int id, string name, string content)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Int32 | id | The Article identifier. |
| System.String | name | The name of the article. |
| System.String | content | The content to be displayed in the article. |
Properties
Id
Gets the identifier.
Declaration
[JsonIgnore]
public int Id { get; }
Property Value
| Type | Description |
|---|---|
| System.Int32 | The identifier. |
PayloadType
Declaration
public string PayloadType { get; }
Property Value
| Type | Description |
|---|---|
| System.String |