Class UpdateMatcher
Inheritance
System.Object
UpdateMatcher
Implements
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class UpdateMatcher : IParameters
Constructors
UpdateMatcher(Int32)
Initializes a new instance of the UpdateMatcher class with the required matcher ID to be updated.
Declaration
public UpdateMatcher(int id)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Int32 | id | The ID of the matcher to update. |
Properties
CompanyId
Gets or sets the hudu company id to make a match for.
Declaration
[JsonProperty("company_id")]
public int CompanyId { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Int32 | The company identifier. |
Id
Gets the identifier for this folder.
Declaration
[JsonIgnore]
public int Id { get; }
Property Value
| Type | Description |
|---|---|
| System.Int32 |
Identifier
Declaration
[JsonProperty("identifier")]
public string Identifier { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String |
PayloadType
Declaration
[JsonIgnore]
public string PayloadType { get; }
Property Value
| Type | Description |
|---|---|
| System.String |
PotentialCompanyId
The suggested hudu company that hudu thinks would match
Declaration
[JsonProperty("potential_company_id")]
public int PotentialCompanyId { get; set; }
Property Value
| Type | Description |
|---|---|
| System.Int32 | The potential company identifier. |
SyncId
This seems to be the company Identifier in the source data. e.g. Connectwise company ID.
Declaration
[JsonProperty("sync_id")]
public string SyncId { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String | The synchronize identifier. |