Class UpdateWebsite
Provides all the properties requried to update a Website using the hudu api endpoint api/v1/websites
Implements
Inherited Members
Namespace: HuduAPI.Endpoints.Parameters
Assembly: HuduAPI.dll
Syntax
public class UpdateWebsite : Website, IParameters
Constructors
UpdateWebsite(Int32, String, Int32)
Initializes a new instance of the UpdateWebsite class with the minimum required properties assigned.
Declaration
public UpdateWebsite(int id, string name, int companyId)
Parameters
| Type | Name | Description |
|---|---|---|
| System.Int32 | id | The identifier of the website to update. |
| System.String | name | The name to set the website too. |
| System.Int32 | companyId | The company identifier the website should be associated with. |
Properties
Id
Gets the identifier of the website to update.
Declaration
public int Id { get; }
Property Value
| Type | Description |
|---|---|
| System.Int32 |
PayloadType
Declaration
public string PayloadType { get; }
Property Value
| Type | Description |
|---|---|
| System.String |