Class RelationEndpoint
Provides all the methods required to make calls to the Relation endpoint of the Hudu API.
Inheritance
Namespace: HuduAPI.Endpoints
Assembly: HuduAPI.dll
Syntax
public class RelationEndpoint
Constructors
RelationEndpoint(String, String)
Initializes a new instance of the RelationEndpoint class with the required API Key and Hudu URL to make all calls.
Declaration
public RelationEndpoint(string huduAPIKey, string huduBaseURL)
Parameters
| Type | Name | Description |
|---|---|---|
| System.String | huduAPIKey | The hudu API key. |
| System.String | huduBaseURL | The hudu base URL. |
Properties
HuduAPIKey
Gets or sets the hudu API key that will be used for all calls to this Endpoint.
Declaration
public string HuduAPIKey { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String | The hudu API key. |
HuduBaseURL
Gets or sets the hudu base URL that will be used for all calls to the Endpoint.
Declaration
public string HuduBaseURL { get; set; }
Property Value
| Type | Description |
|---|---|
| System.String | The hudu base URL. |
Methods
Create(CreateRelation)
Creates a new Relation in Hudu using the provided parameters
Declaration
public Relation Create(CreateRelation parameters)
Parameters
| Type | Name | Description |
|---|---|---|
| CreateRelation | parameters | The parameters to use when making the call. |
Returns
| Type | Description |
|---|---|
| Relation | An object of type |
Delete(ItemById)
Delete the specified Relation from Hudu
Declaration
public void Delete(ItemById parameters)
Parameters
| Type | Name | Description |
|---|---|---|
| ItemById | parameters | The Relation ID to use when making the call. |
Get(GetRelations)
Get a list of Relation objects from the Hudu Endpoint
Declaration
public Relations Get(GetRelations parameters)
Parameters
| Type | Name | Description |
|---|---|---|
| GetRelations | parameters | The parameters to use when making the call. |
Returns
| Type | Description |
|---|---|
| Relations | A Relations objec that contains a list of Relations found in hudu |