Namespace HuduAPI.Records
Classes
ActivityLog
Represents a returned ActivityLog from the Hudu API endpoint activity_logs
ActivityLogs
Represents a list of ActivityLog entries
APIInfo
Represents the returned API Info data from the Hudu API endpoint api/v1/api_info
Article
Represents a single Article returned from the Hudu API
Articles
Represents a list of articles returned from the Hudu API. Its a very basic class with a indexer to allow getting an article by name or id
Asset
Represents a single Asset returned from the Hudu API endpoint assets
AssetLayout
Represents a single asset_layout returned from the Hudu API
AssetLayout.AssetLayoutField
Represents a single Field within an AssetLayout that describes the asset.
AssetLayouts
Represents a list of asset_layouts returned from the Hudu API
AssetPassword
Represents an Asset Password returned from the Hudu API.
AssetPasswords
Represents a list of Asset Passwords returned from the Hudu api endpoint asset_passwords
Assets
Represents a list of Assets returned from the Hudu endpoint assets
Companies
Companies represents the list of companies returned from a call to the Companies Endpoint.
Company
Represents a Hudu Company and all its attributes as provided by the Hudu API
Company.Integration
Any API integrations that may be enabled for the company
Expiration
Represents the objects returned from the Hudu endpoint Expirations
Field
Represents a Field within the Asset Layout.
Folder
Represents a single folder object returned from the Hudu API endpoing folders
Folders
Represents a list of Folder objects returned from the Hudud Endpont
MagicDash
Represents a single MagicDash object returned from the hudu API endpoint magic_dash
MagicDashes
Matcher
Matchers are used by integrations to match external data to internal hudu companies.
Matchers
A list of Matchers items
Procedure
Represents a single procedure object returned from the API endpoint procedures
Procedures
Represents a list of procedure objects returned from the Hudu API endpoing procedures.
ProcedureTasksAttribute
Represents Attributes about a Procedure object returned from the Hudu API endpoint procedures
PublicPhoto
Represents the photo objects attached to an article
Relation
Represents a single Relation object returned from the Hudu API
Relations
Represents a list of Relation objects that are returned from the Hudu API
Website
Represents a single website object returned from the Hudu API endpoint websites