Class Articles
Represents a list of articles returned from the Hudu API. Its a very basic class with a indexer to allow getting an article by name or id
Inheritance
System.Object
Articles
Implements
Namespace: HuduAPI.Records
Assembly: HuduAPI.dll
Syntax
public class Articles : IRecord
Properties
ArticleList
Declaration
[JsonProperty("articles")]
public IList<Article> ArticleList { get; set; }
Property Value
| Type | Description |
|---|---|
| IList<Article> |
Item[Int32]
Gets the System.Nullable<T> with the specified identifier. If no Article exists then returns null.
Declaration
public Article this[int id] { get; }
Parameters
| Type | Name | Description |
|---|---|---|
| System.Int32 | id | The Article ID. |
Property Value
| Type | Description |
|---|---|
| Article | The System.Nullable<T> with the ID value equal to id. |
Item[Int32, String]
Gets the System.Nullable<T> with the specified name for the specified company. If no Article exists then null is returned
Declaration
public Article this[int company, string name] { get; }
Parameters
| Type | Name | Description |
|---|---|---|
| System.Int32 | company | The company ID to search for articles in. |
| System.String | name | The name of the article to search for. |
Property Value
| Type | Description |
|---|---|
| Article | The System.Nullable<T>. |