Class Procedures
Represents a list of procedure objects returned from the Hudu API endpoing procedures.
Inheritance
System.Object
Procedures
Implements
Namespace: HuduAPI.Records
Assembly: HuduAPI.dll
Syntax
public class Procedures : IRecord
Properties
Item[Int32]
Gets the System.Nullable<T> with the specified identifier. Will return null if no procedure exists for the id supplied
Declaration
public Procedure this[int id] { get; }
Parameters
| Type | Name | Description |
|---|---|---|
| System.Int32 | id | The identifier of the procedure. |
Property Value
| Type | Description |
|---|---|
| Procedure | A Procedure object if found, or null if not. |
ProcedureList
Declaration
[JsonProperty("procedures")]
public IList<Procedure> ProcedureList { get; set; }
Property Value
| Type | Description |
|---|---|
| IList<Procedure> |